( cd usr/share/icons/gnome/22x22/emblems ; rm -rf emblem-noread.png )
( cd usr/share/icons/gnome/22x22/emblems ; ln -sf emblem-unreadable.png emblem-noread.png )
( cd usr/share/icons/gnome/22x22/emblems ; rm -rf stock_mail-priority-high.png )
( cd usr/share/icons/gnome/22x22/emblems ; ln -sf emblem-important.png stock_mail-priority-high.png )
( cd usr/share/icons/gnome/22x22/emblems ; rm -rf emblem-nowrite.png )
( cd usr/share/icons/gnome/22x22/emblems ; ln -sf emblem-readonly.png emblem-nowrite.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png gnome-mime-text.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf html.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png html.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf image-x-generic.png image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf www.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png www.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf stock_script.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png stock_script.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-address-book.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf document.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png document.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf rpm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png rpm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf vcard.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-address-book.png vcard.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf image-x-generic.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-fs-regular.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-preview.png gnome-fs-regular.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png gnome-mime-text-html.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf zip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png zip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf exec.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-x-executable.png exec.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf shellscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png shellscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf txt2.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png txt2.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf folder_tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png folder_tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-fs-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-x-executable.png gnome-fs-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-audio.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf audio-x-generic.png gnome-mime-audio.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf package.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png package.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf empty.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png empty.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf unknown.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png unknown.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf sound.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf audio-x-generic.png sound.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-package.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf stock_certificate.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-certificate.png stock_certificate.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf font_bitmap.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png font_bitmap.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf audio-x-generic.png gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png spreadsheet.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf contents2.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-address-book.png contents2.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf mime_ascii.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png mime_ascii.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf package_editors.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png package_editors.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf misc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png misc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf template_source.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic-template.png template_source.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf wordprocessing.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png wordprocessing.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf image-x-generic.png gnome-mime-image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf kpresenter_kpr.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png kpresenter_kpr.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf stock_addressbook.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-address-book.png stock_addressbook.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf stock_calendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-calendar.png stock_calendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf font.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png font.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf binary.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-x-executable.png binary.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf vcalendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-calendar.png vcalendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-html.png gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-calendar.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf ascii.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png ascii.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf plan.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-calendar.png plan.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf tgz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png tgz.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf package_wordprocessing.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png package_wordprocessing.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf txt.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-generic.png txt.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf video.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png video.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf font_truetype.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png font_truetype.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf font_type1.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf font-x-generic.png font_type1.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gtk-file.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf text-x-preview.png gtk-file.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf x-office-document.png gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf gnome-mime-video.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf video-x-generic.png gnome-mime-video.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; rm -rf deb.png )
( cd usr/share/icons/gnome/22x22/mimetypes ; ln -sf package-x-generic.png deb.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-multimedia.png gnome-multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-globe.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-internet.png gnome-globe.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-applications.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-office.png gnome-applications.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce4-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png xfce4-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-sound_video.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-multimedia.png redhat-sound_video.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-system.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-system.png gnome-system.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-control-center.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png gnome-control-center.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-multimedia.png xfce-multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-system_tools.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-system.png redhat-system_tools.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-preferences.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png redhat-preferences.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-graphics.png xfce-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png gnome-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-joystick.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-games.png gnome-joystick.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-office.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-office.png xfce-office.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-internet.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-internet.png redhat-internet.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-system-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-system.png xfce-system-settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_system.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-system.png package_system.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-internet.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-internet.png xfce-internet.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-office.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-office.png redhat-office.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-system.png package_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-programming.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-development.png redhat-programming.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_network.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-internet.png package_network.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_games.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-games.png package_games.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-graphics.png gnome-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_development.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-development.png package_development.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-games.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-games.png xfce-games.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_utilities.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-accessories.png package_utilities.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-graphics.png redhat-graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-util.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-accessories.png gnome-util.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf kcontrol.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png kcontrol.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-accessories.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-accessories.png redhat-accessories.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-multimedia.png package_multimedia.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf stock_internet.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-internet.png stock_internet.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-games.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-games.png redhat-games.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf redhat-system_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-system.png redhat-system_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-other.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-other.png gnome-other.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf input_devices_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop-peripherals.png input_devices_settings.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gtk-preferences.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf preferences-desktop.png gtk-preferences.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_office.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-office.png package_office.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf gnome-devel.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-development.png gnome-devel.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf package_graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-graphics.png package_graphics.png )
( cd usr/share/icons/gnome/22x22/categories ; rm -rf xfce-utils.png )
( cd usr/share/icons/gnome/22x22/categories ; ln -sf applications-accessories.png xfce-utils.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf printer1.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png printer1.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf cdwriter_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png cdwriter_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf stock_printers.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png stock_printers.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-floppy.png gnome-dev-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-flash.png gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-flash.png gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-computer.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf computer.png gnome-dev-computer.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-optical.png gnome-dev-dvd.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gtk-harddisk.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png gtk-harddisk.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf stock_mic.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf audio-input-microphone.png stock_mic.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf xfce4-keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-keyboard.png xfce4-keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-mouse.png yast_mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf network-wired.png gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_idetude.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png yast_idetude.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf harddrive.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png harddrive.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_soundcard.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf audio-card.png yast_soundcard.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf ipod_mount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf multimedia-player.png ipod_mount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-fs-client.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf computer.png gnome-fs-client.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf kxkb.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-keyboard.png kxkb.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-keyboard.png keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf drive-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-optical.png drive-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-zip.png gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf usbpendrive_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-removable-media.png usbpendrive_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf cdrom_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png cdrom_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf display.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf video-display.png display.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-removable-media.png gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-battery.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf battery.png gnome-dev-battery.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-mouse.png mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf joystick.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-gaming.png joystick.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf 3floppy_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-floppy.png 3floppy_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-removable-media.png gnome-dev-removable.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gtk-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gtk-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf dvd_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png dvd_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-mouse.png gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf media-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png media-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-optical.png gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-keyboard.png gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_joystick.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-gaming.png yast_joystick.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-ipod.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf multimedia-player.png gnome-dev-ipod.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf xfce4-display.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf video-display.png xfce4-display.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf network-wireless.png gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf xfce-printer.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png xfce-printer.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf system-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-floppy.png system-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf printer-remote.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png printer-remote.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-flash.png gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-stock-mic.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf audio-input-microphone.png gnome-stock-mic.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf camera_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf camera-photo.png camera_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-modem.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf modem.png gnome-modem.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf camera.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf camera-photo.png camera.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-printer.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png gnome-dev-printer.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-flash.png gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf stock_cell-phone.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf phone.png stock_cell-phone.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf xfce4-mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-mouse.png xfce4-mouse.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf system.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf computer.png system.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gtk-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-floppy.png gtk-floppy.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_printer.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png yast_printer.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf input-mouse.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf hdd_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png hdd_unmount.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf printmgr.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png printmgr.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf yast_HD.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png yast_HD.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-removable-media.png gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf kjobviewer.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf printer.png kjobviewer.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf chardevice.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf video-display.png chardevice.png )
( cd usr/share/icons/gnome/22x22/devices ; rm -rf gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/22x22/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-transmit-receive.png gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf folder-visiting.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_repeat.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf media-playlist-repeat.png stock_repeat.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_dialog-warning.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-warning.png stock_dialog-warning.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_lock-ok.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf security-high.png stock_lock-ok.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_mail-unread.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf mail-unread.png stock_mail-unread.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-password.png gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_lock-open.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf security-low.png stock_lock-open.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-missing-image.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf image-missing.png gtk-missing-image.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf appointment-missed.png stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf folder_open.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf folder-open.png folder_open.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf connect_no.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-offline.png connect_no.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf messagebox_info.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-information.png messagebox_info.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf edittrash.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png edittrash.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-cloudy.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-overcast.png stock_weather-cloudy.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-night-clear.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-clear-night.png stock_weather-night-clear.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-few-clouds.png stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-dialog-warning.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-warning.png gtk-dialog-warning.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-dialog-question.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-question.png gtk-dialog-question.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume-med.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-medium.png stock_volume-med.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-error.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-error.png gnome-netstatus-error.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_attach.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf mail-attachment.png stock_attach.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf xfce-trash_full.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png xfce-trash_full.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf nm-device-wired.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-idle.png nm-device-wired.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-transmit.png gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_appointment-reminder.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf appointment-soon.png stock_appointment-reminder.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_lock.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf security-medium.png stock_lock.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf folder-drag-accept.png gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-wireless-encrypted.png gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf info.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-information.png info.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-receive.png gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf trashcan_full.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png trashcan_full.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf nm-no-connection.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-offline.png nm-no-connection.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf connect_creating.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-transmit-receive.png connect_creating.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-idle.png gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-high.png stock_volume.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-dialog-error.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-error.png gtk-dialog-error.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf error.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-error.png error.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_mail-open.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf mail-read.png stock_mail-open.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf image-loading.png gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_trash_full.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png stock_trash_full.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-showers.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-showers.png stock_weather-showers.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-few-clouds-night.png stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_dialog-error.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-error.png stock_dialog-error.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-fog.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-fog.png stock_weather-fog.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-storm.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-storm.png stock_weather-storm.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume-0.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-low.png stock_volume-0.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-offline.png gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf connect_established.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-idle.png connect_established.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf nm-adhoc.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-idle.png nm-adhoc.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-sunny.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-clear.png stock_weather-sunny.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gtk-dialog-info.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-information.png gtk-dialog-info.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_lock-broken.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf security-low.png stock_lock-broken.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_dialog-info.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-information.png stock_dialog-info.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf important.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-warning.png important.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf user-trash-full.png gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume-min.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-low.png stock_volume-min.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_mail-replied.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf mail-replied.png stock_mail-replied.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_open.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf folder-open.png stock_open.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf messagebox_critical.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-error.png messagebox_critical.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_weather-snow.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-snow.png stock_weather-snow.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_shuffle.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf media-playlist-shuffle.png stock_shuffle.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf messagebox_warning.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-warning.png messagebox_warning.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume-max.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-high.png stock_volume-max.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_volume-mute.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf audio-volume-muted.png stock_volume-mute.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf nm-device-wireless.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf network-idle.png nm-device-wireless.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf sunny.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf weather-clear.png sunny.png )
( cd usr/share/icons/gnome/22x22/status ; rm -rf stock_dialog-question.png )
( cd usr/share/icons/gnome/22x22/status ; ln -sf dialog-question.png stock_dialog-question.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-character-map.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-character-map.png gnome-character-map.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-settings-font.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-font.png gnome-settings-font.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf style.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-theme.png style.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-help.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png gnome-help.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xscreensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-screensaver.png xscreensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf screensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-screensaver.png screensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf locale.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-locale.png locale.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xfce4-backdrop.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-wallpaper.png xfce4-backdrop.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf openterm.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-terminal.png openterm.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf ksysguard.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-system-monitor.png ksysguard.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xfce4-mixer.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png xfce4-mixer.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-mixer.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png gnome-mixer.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf config-language.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-locale.png config-language.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf config-users.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-users.png config-users.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kcalc.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-calculator.png kcalc.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf wallpaper.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-wallpaper.png wallpaper.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-settings-background.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-wallpaper.png gnome-settings-background.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf accessibility-directory.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-accessibility.png accessibility-directory.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-terminal.png gnome-terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf update-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-software-update.png update-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf stock_help.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png stock_help.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-accessibility.png gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf key_bindings.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png key_bindings.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kcmkwm.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-system-windows.png kcmkwm.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xfce-terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-terminal.png xfce-terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf volume-knob.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png volume-knob.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gucharmap.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-character-map.png gucharmap.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf multimedia.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png multimedia.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-system-monitor.png gnome-monitor.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kuser.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-users.png kuser.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf redhat-filemanager.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-file-manager.png redhat-filemanager.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf zen-icon.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-software-update.png zen-icon.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-settings-theme.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-theme.png gnome-settings-theme.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kedit.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-text-editor.png kedit.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf help.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png help.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xfce-filemanager.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-file-manager.png xfce-filemanager.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf calc.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-calculator.png calc.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kcharselect.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-character-map.png kcharselect.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf arts.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png arts.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-remote-desktop.png gnome-remote-desktop.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gtk-help.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png gtk-help.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf background.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-wallpaper.png background.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf file-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-file-manager.png file-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-window-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-system-windows.png gnome-window-manager.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf access.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-accessibility.png access.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kfm.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-file-manager.png kfm.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kscreensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-screensaver.png kscreensaver.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf khelpcenter.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png khelpcenter.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf xfwm4.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-system-windows.png xfwm4.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kwin.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-system-windows.png kwin.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf gnome-calculator.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-calculator.png gnome-calculator.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf system-config-users.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf system-users.png system-config-users.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-terminal.png terminal.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf susehelpcenter.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf help-browser.png susehelpcenter.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf krfb.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-remote-desktop.png krfb.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf text-editor.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf accessories-text-editor.png text-editor.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf kcmsound.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf multimedia-volume-control.png kcmsound.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf konsole.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf utilities-terminal.png konsole.png )
( cd usr/share/icons/gnome/22x22/apps ; rm -rf fonts.png )
( cd usr/share/icons/gnome/22x22/apps ; ln -sf preferences-desktop-font.png fonts.png )
( cd usr/share/icons/gnome/22x22/animations ; rm -rf gnome-spinner-rest.png )
( cd usr/share/icons/gnome/22x22/animations ; ln -sf process-idle.png gnome-spinner-rest.png )
( cd usr/share/icons/gnome/22x22/animations ; rm -rf gnome-spinner.png )
( cd usr/share/icons/gnome/22x22/animations ; ln -sf process-working.png gnome-spinner.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-8.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-plain.png stock_smiley-8.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-15.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-cool.png stock_smiley-15.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-1.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-smile.png stock_smiley-1.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-11.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-crying.png stock_smiley-11.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-10.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-raspberry.png stock_smiley-10.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-2.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-smile.png stock_smiley-2.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-13.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-kiss.png stock_smiley-13.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-4.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-sad.png stock_smiley-4.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-5.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-surprise.png stock_smiley-5.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-3.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-wink.png stock_smiley-3.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-18.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-angel.png stock_smiley-18.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-7.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-smile.png stock_smiley-7.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-6.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-smile-big.png stock_smiley-6.png )
( cd usr/share/icons/gnome/22x22/emotes ; rm -rf stock_smiley-22.png )
( cd usr/share/icons/gnome/22x22/emotes ; ln -sf face-monkey.png stock_smiley-22.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-server.png gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf novell-button.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf start-here.png novell-button.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf redhat-network-server.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-server.png redhat-network-server.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gtk-directory.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.png gtk-directory.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf desktop.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-desktop.png desktop.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-fs-ssh.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf distributor-logo.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf start-here.png distributor-logo.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-workgroup.png gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf trashcan_empty.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-trash.png trashcan_empty.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-saved-search.png application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf xfce-trash_empty.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-trash.png xfce-trash_empty.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-fs-ftp.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gtk-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.icon gtk-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-stock-trash.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-trash.png gnome-stock-trash.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf emptytrash.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-trash.png emptytrash.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gtk-network.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-workgroup.png gtk-network.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf stock_folder.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.png stock_folder.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-main-menu.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf start-here.png gnome-main-menu.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-server.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-server.png gnome-fs-server.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-directory.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.png gnome-fs-directory.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf folder_home.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-home.png folder_home.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-share.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-fs-share.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf stock_folder.icon )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.icon stock_folder.icon )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-trash.png gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf network.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png network.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf inode-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.icon inode-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-network.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-workgroup.png gnome-fs-network.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-home.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-home.png gnome-fs-home.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-desktop.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf user-desktop.png gnome-fs-desktop.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-server.png gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-fs-nfs.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf network_local.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-workgroup.png network_local.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf inode-directory.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.png inode-directory.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf server.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf network-server.png server.png )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder.icon gnome-fs-directory.icon )
( cd usr/share/icons/gnome/22x22/places ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/gnome/22x22/places ; ln -sf folder-remote.png gnome-fs-smb.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf viewmag-.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-out.png viewmag-.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_save.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save.png stock_save.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-run.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-run.png gnome-run.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf editdelete.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-delete.png editdelete.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf zoom-best-fit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-fit-best.png zoom-best-fit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_pause.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-pause.png player_pause.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_end.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-forward.png player_end.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-last.png gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_right.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-next.png stock_right.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_up.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-up.png stock_up.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_spellcheck.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf tools-check-spelling.png stock_spellcheck.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf editcopy.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-copy.png editcopy.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_delete.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-delete.png stock_delete.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_home.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-home.png stock_home.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf kfm_home.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-home.png kfm_home.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-cancel.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf process-stop.png gtk-cancel.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_right.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-right.png stock_text_right.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-zoom-out.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-out.png gtk-zoom-out.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_replyall.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-reply-all.png mail_replyall.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-dir.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf folder-new.png stock_new-dir.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf rightjust.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-right.png rightjust.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-new.png gtk-new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-backward.png gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_undo.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-undo.png stock_undo.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-about.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf help-about.png gtk-about.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-indent-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-more.png gtk-indent-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-close.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf window-close.png gtk-close.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-sort-descending.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-sort-descending.png gtk-sort-descending.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_forward.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-forward.png mail_forward.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf editcut.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-cut.png editcut.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-select-all.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-select-all.png gtk-select-all.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf process-stop.png gtk-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_save-as.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save-as.png stock_save-as.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-undo-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-undo.png gtk-undo-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_zoom-1.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-original.png stock_zoom-1.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-forward.png stock_media-fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-message-new.png mail_new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-top.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-top.png gtk-goto-top.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_search.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find.png stock_search.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf lock.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-lock-screen.png lock.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-justify-right.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-right.png gtk-justify-right.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-next.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-forward.png stock_media-next.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-less.png gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-start.png gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_center.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-center.png stock_text_center.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_add-bookmark.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf bookmark-new.png stock_add-bookmark.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-reply-all.png stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-record.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-record.png gtk-media-record.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf tab_new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf tab-new.png tab_new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-justify-center.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-center.png gtk-justify-center.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf kfind.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-search.png kfind.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-bcard.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf contact-new.png stock_new-bcard.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf viewmag+.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-in.png viewmag+.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf reload_page.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png reload_page.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-underline.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-underline.png gtk-underline.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf folder_new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf folder-new.png folder_new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-revert.png gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-clear.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-clear.png gtk-clear.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf process-stop.png stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-next.png gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_spam.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-mark-junk.png stock_spam.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-forward.png gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-bottom.png gtk-goto-bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-zoom-100.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-original.png gtk-zoom-100.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf fileopen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-open.png fileopen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-zoom-fit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-fit-best.png gtk-zoom-fit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_send.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-send.png mail_send.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf filesaveas.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save-as.png filesaveas.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf redhat-home.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-home.png redhat-home.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-forward.png gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-bottom.png stock_bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-jump.png gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-stop.png gtk-media-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf previous.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-previous.png previous.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-fullscreen.png gtk-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-print.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print.png gtk-print.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_zoom-in.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-in.png stock_zoom-in.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_redo.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-redo.png stock_redo.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_first.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-first.png stock_first.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-cut.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-cut.png gtk-cut.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-shutdown.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-shutdown.png gnome-shutdown.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf reload3.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png reload3.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-prev.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-backward.png stock_media-prev.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-revert.png gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-print-preview.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print-preview.png gtk-print-preview.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf bookmark_add.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf bookmark-new.png bookmark_add.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-bottom.png bottom.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_properties.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-properties.png stock_properties.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-stop.png player_stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_rew.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-backward.png player_rew.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf viewmagfit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-fit-best.png viewmagfit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf process-stop.png stock_stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-reply-sender.png gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_select-all.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-select-all.png stock_select-all.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_top.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-top.png stock_top.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-more.png gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf exit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf application-exit.png exit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-italic.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-italic.png gtk-italic.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf viewmag1.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-original.png viewmag1.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf xfce-system-exit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf application-exit.png xfce-system-exit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf revert.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-revert.png revert.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text-strikethrough.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-strikethrough.png stock_text-strikethrough.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-send.png gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-find-and-replace.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find-replace.png gtk-find-and-replace.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf bookmark-new.png stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-quit.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf application-exit.png gtk-quit.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-previous.png gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-reply.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-reply-sender.png stock_mail-reply.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-zoom-in.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-in.png gtk-zoom-in.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf window_nofullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-restore.png window_nofullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-jump.png gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf redo.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-redo.png redo.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf text_strike.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-strikethrough.png text_strike.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_left.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-left.png stock_text_left.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_about.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf help-about.png stock_about.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf reload_all_tabs.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png reload_all_tabs.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_zoom-out.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-out.png stock_zoom-out.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_reply.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-reply-sender.png mail_reply.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf editpaste.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-paste.png editpaste.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_indent.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-more.png stock_text_indent.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-lock-screen.png gnome-lockscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_print-setup.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-page-setup.png stock_print-setup.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-down.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-down.png gtk-go-down.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_italic.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-italic.png stock_text_italic.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf xfce-system-lock.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-lock-screen.png xfce-system-lock.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf add.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf list-add.png add.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-redo-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-redo.png gtk-redo-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-forward.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-forward.png stock_mail-forward.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_last.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-last.png stock_last.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf bookmarks_list_add.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf bookmark-new.png bookmarks_list_add.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_underlined.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-underline.png stock_text_underlined.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-last.png gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf filesave.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save.png filesave.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-forward.png gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-justify-fill.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-fill.png gtk-justify-fill.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-indent-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-less.png gtk-indent-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf down.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-down.png down.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-send.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-send.png stock_mail-send.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-more.png gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_close.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf window-close.png stock_close.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf search.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-search.png search.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_zoom-page.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf zoom-fit-best.png stock_zoom-page.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-compose.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-message-new.png stock_mail-compose.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf next.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-next.png next.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-spell-check.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf tools-check-spelling.png gtk-spell-check.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-searchtool.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-search.png gnome-searchtool.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-justify-left.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-left.png gtk-justify-left.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf remove.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf list-remove.png remove.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-up.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-up.png gtk-go-up.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-find.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find.png gtk-find.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-less.png gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-delete.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-delete.png gtk-delete.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-remove.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf list-remove.png gtk-remove.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-pause.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-pause.png gtk-media-pause.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-rec.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-record.png stock_media-rec.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-forward.png gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-restore.png gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf text_italic.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-italic.png text_italic.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-appointment.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf appointment-new.png stock_new-appointment.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-message-new.png gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-bold.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-bold.png gtk-bold.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-home.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-home.png gtk-home.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-tab.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf tab-new.png stock_new-tab.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_paste.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-paste.png stock_paste.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_record.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-record.png player_record.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_refresh.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png stock_refresh.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf editclear.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-clear.png editclear.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_down.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-down.png stock_down.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-refresh.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png gtk-refresh.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-forward.png gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf text_under.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-underline.png text_under.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf filenew.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-new.png filenew.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-address-book.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf address-book-new.png stock_new-address-book.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_print-preview.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print-preview.png stock_print-preview.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf filequickprint.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print-preview.png filequickprint.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-backward.png gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_search-and-replace.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find-replace.png stock_search-and-replace.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf window_fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-fullscreen.png window_fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf forward.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-next.png forward.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-paste.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-paste.png gtk-paste.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf leftjust.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-left.png leftjust.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-copy.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-copy.png gtk-copy.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf up.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-up.png up.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-previous.png gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-forward.png player_fwd.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf text_bold.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-bold.png text_bold.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-pause.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-pause.png stock_media-pause.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-save-as.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save-as.png gtk-save-as.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf window_new.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf window-new.png window_new.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gohome.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-home.png gohome.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-execute.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-run.png gtk-execute.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-first.png gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-restore.png stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gnome-logout.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf system-log-out.png gnome-logout.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_justify.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-fill.png stock_text_justify.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf top.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-top.png top.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-fullscreen.png stock_fullscreen.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-strikethrough.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-strikethrough.png gtk-strikethrough.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-window.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf window-new.png stock_new-window.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_play.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-start.png player_play.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-next.png gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf filefind.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find.png filefind.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf back.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-previous.png back.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf undo.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-undo.png undo.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_new-text.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-new.png stock_new-text.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf reload.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-refresh.png reload.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf mail_spam.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-mark-junk.png mail_spam.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_start.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-backward.png player_start.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf player_eject.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-eject.png player_eject.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-backward.png gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf fileprint.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print.png fileprint.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_left.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-previous.png stock_left.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-first.png gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_cut.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-cut.png stock_cut.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf find.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-find.png find.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf finish.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-last.png finish.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-play.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-start.png stock_media-play.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_unindent.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-indent-less.png stock_text_unindent.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-open.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-open.png gtk-open.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_file-properites.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-properties.png stock_file-properites.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf start.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf go-first.png start.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-sort-ascending.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf view-sort-ascending.png gtk-sort-ascending.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-save.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-save.png gtk-save.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf centrejust.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-justify-center.png centrejust.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_mail-send-receive.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf mail-send-receive.png stock_mail-send-receive.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_print.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-print.png stock_print.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-skip-backward.png gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-properties.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf document-properties.png gtk-properties.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-playback-stop.png stock_media-stop.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_copy.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf edit-copy.png stock_copy.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_media-rew.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf media-seek-backward.png stock_media-rew.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf stock_text_bold.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf format-text-bold.png stock_text_bold.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf gtk-add.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf list-add.png gtk-add.png )
( cd usr/share/icons/gnome/22x22/actions ; rm -rf appointment.png )
( cd usr/share/icons/gnome/22x22/actions ; ln -sf appointment-new.png appointment.png )
( cd usr/share/icons/gnome/48x48/devices ; rm -rf gnome-dev-jazdisk.png )
( cd usr/share/icons/gnome/48x48/devices ; ln -sf media-jaz.png gnome-dev-jazdisk.png )
( cd usr/share/icons/gnome/48x48/animations ; rm -rf gnome-searchtool-animation.png )
( cd usr/share/icons/gnome/48x48/animations ; ln -sf process-working.png gnome-searchtool-animation.png )
( cd usr/share/icons/gnome/48x48/animations ; rm -rf gnome-searchtool-animation-rest.png )
( cd usr/share/icons/gnome/48x48/animations ; ln -sf process-idle.png gnome-searchtool-animation-rest.png )
( cd usr/share/icons/gnome/48x48/animations ; rm -rf gnome-spinner-rest.png )
( cd usr/share/icons/gnome/48x48/animations ; ln -sf process-idle.png gnome-spinner-rest.png )
( cd usr/share/icons/gnome/48x48/animations ; rm -rf gnome-spinner.png )
( cd usr/share/icons/gnome/48x48/animations ; ln -sf process-working.png gnome-spinner.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf stock_not-spam.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-mark-not-junk.png stock_not-spam.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf mail_new.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-message-new.png mail_new.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf stock_spam.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-mark-junk.png stock_spam.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf stock_mail-compose.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-message-new.png stock_mail-compose.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf stock_new-appointment.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf appointment-new.png stock_new-appointment.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-message-new.png gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf mail_spam.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-mark-junk.png mail_spam.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf stock_mail-send-receive.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf mail-send-receive.png stock_mail-send-receive.png )
( cd usr/share/icons/gnome/48x48/actions ; rm -rf appointment.png )
( cd usr/share/icons/gnome/48x48/actions ; ln -sf appointment-new.png appointment.png )
( cd usr/share/icons/gnome/24x24/emblems ; rm -rf emblem-noread.png )
( cd usr/share/icons/gnome/24x24/emblems ; ln -sf emblem-unreadable.png emblem-noread.png )
( cd usr/share/icons/gnome/24x24/emblems ; rm -rf stock_mail-priority-high.png )
( cd usr/share/icons/gnome/24x24/emblems ; ln -sf emblem-important.png stock_mail-priority-high.png )
( cd usr/share/icons/gnome/24x24/emblems ; rm -rf emblem-nowrite.png )
( cd usr/share/icons/gnome/24x24/emblems ; ln -sf emblem-readonly.png emblem-nowrite.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png gnome-mime-text.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf html.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png html.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf image-x-generic.png image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf www.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png www.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf stock_script.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png stock_script.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-address-book.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf document.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png document.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf rpm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png rpm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf vcard.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-address-book.png vcard.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf image-x-generic.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-fs-regular.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-preview.png gnome-fs-regular.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png gnome-mime-text-html.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf zip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png zip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf exec.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-x-executable.png exec.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf shellscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png shellscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf txt2.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png txt2.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf folder_tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png folder_tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-fs-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-x-executable.png gnome-fs-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-audio.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf audio-x-generic.png gnome-mime-audio.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf package.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png package.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf empty.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png empty.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf unknown.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png unknown.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf sound.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf audio-x-generic.png sound.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-package.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf stock_certificate.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-certificate.png stock_certificate.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf font_bitmap.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png font_bitmap.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf audio-x-generic.png gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png spreadsheet.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf contents2.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-address-book.png contents2.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf mime_ascii.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png mime_ascii.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf package_editors.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png package_editors.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf misc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png misc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf template_source.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic-template.png template_source.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf wordprocessing.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png wordprocessing.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf image-x-generic.png gnome-mime-image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf kpresenter_kpr.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png kpresenter_kpr.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf stock_addressbook.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-address-book.png stock_addressbook.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf stock_calendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-calendar.png stock_calendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf font.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png font.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf binary.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-x-executable.png binary.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf vcalendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-calendar.png vcalendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-html.png gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-calendar.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf ascii.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png ascii.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf plan.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-calendar.png plan.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf tgz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png tgz.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf package_wordprocessing.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png package_wordprocessing.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf txt.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-generic.png txt.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf video.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png video.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf font_truetype.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png font_truetype.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf font_type1.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf font-x-generic.png font_type1.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gtk-file.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf text-x-preview.png gtk-file.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf x-office-document.png gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf gnome-mime-video.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf video-x-generic.png gnome-mime-video.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; rm -rf deb.png )
( cd usr/share/icons/gnome/24x24/mimetypes ; ln -sf package-x-generic.png deb.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-multimedia.png gnome-multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-globe.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-internet.png gnome-globe.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-applications.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-office.png gnome-applications.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce4-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png xfce4-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-sound_video.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-multimedia.png redhat-sound_video.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-system.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-system.png gnome-system.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-control-center.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png gnome-control-center.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-multimedia.png xfce-multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-system_tools.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-system.png redhat-system_tools.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-preferences.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png redhat-preferences.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-graphics.png xfce-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png gnome-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-joystick.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-games.png gnome-joystick.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-office.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-office.png xfce-office.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-internet.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-internet.png redhat-internet.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-system-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-system.png xfce-system-settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_system.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-system.png package_system.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-internet.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-internet.png xfce-internet.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-office.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-office.png redhat-office.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-system.png package_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-programming.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-development.png redhat-programming.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_network.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-internet.png package_network.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_games.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-games.png package_games.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-graphics.png gnome-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_development.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-development.png package_development.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-games.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-games.png xfce-games.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_utilities.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-accessories.png package_utilities.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-graphics.png redhat-graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-util.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-accessories.png gnome-util.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf kcontrol.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png kcontrol.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-accessories.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-accessories.png redhat-accessories.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-multimedia.png package_multimedia.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf stock_internet.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-internet.png stock_internet.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-games.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-games.png redhat-games.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf redhat-system_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-system.png redhat-system_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-other.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-other.png gnome-other.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf input_devices_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop-peripherals.png input_devices_settings.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gtk-preferences.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf preferences-desktop.png gtk-preferences.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_office.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-office.png package_office.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf gnome-devel.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-development.png gnome-devel.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf package_graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-graphics.png package_graphics.png )
( cd usr/share/icons/gnome/24x24/categories ; rm -rf xfce-utils.png )
( cd usr/share/icons/gnome/24x24/categories ; ln -sf applications-accessories.png xfce-utils.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf printer1.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png printer1.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf cdwriter_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png cdwriter_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf stock_printers.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png stock_printers.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-floppy.png gnome-dev-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-flash.png gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-flash.png gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-computer.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf computer.png gnome-dev-computer.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-optical.png gnome-dev-dvd.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gtk-harddisk.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png gtk-harddisk.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf stock_mic.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf audio-input-microphone.png stock_mic.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf xfce4-keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-keyboard.png xfce4-keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-mouse.png yast_mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf network-wired.png gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_idetude.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png yast_idetude.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf harddrive.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png harddrive.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_soundcard.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf audio-card.png yast_soundcard.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf ipod_mount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf multimedia-player.png ipod_mount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-fs-client.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf computer.png gnome-fs-client.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf kxkb.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-keyboard.png kxkb.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-keyboard.png keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf drive-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-optical.png drive-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-zip.png gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf usbpendrive_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-removable-media.png usbpendrive_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf cdrom_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png cdrom_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf display.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf video-display.png display.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-removable-media.png gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-battery.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf battery.png gnome-dev-battery.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-mouse.png mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf joystick.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-gaming.png joystick.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf 3floppy_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-floppy.png 3floppy_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-removable-media.png gnome-dev-removable.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gtk-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gtk-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf dvd_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png dvd_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-mouse.png gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf media-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png media-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-optical.png gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-keyboard.png gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_joystick.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-gaming.png yast_joystick.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-ipod.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf multimedia-player.png gnome-dev-ipod.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf xfce4-display.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf video-display.png xfce4-display.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf network-wireless.png gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf xfce-printer.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png xfce-printer.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf system-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-floppy.png system-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf printer-remote.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png printer-remote.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-flash.png gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-stock-mic.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf audio-input-microphone.png gnome-stock-mic.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf camera_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf camera-photo.png camera_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-modem.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf modem.png gnome-modem.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf camera.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf camera-photo.png camera.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-printer.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png gnome-dev-printer.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-flash.png gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf stock_cell-phone.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf phone.png stock_cell-phone.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf xfce4-mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-mouse.png xfce4-mouse.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf system.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf computer.png system.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gtk-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-floppy.png gtk-floppy.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_printer.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png yast_printer.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf input-mouse.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf hdd_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png hdd_unmount.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf printmgr.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png printmgr.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf yast_HD.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png yast_HD.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-removable-media.png gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf kjobviewer.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf printer.png kjobviewer.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf chardevice.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf video-display.png chardevice.png )
( cd usr/share/icons/gnome/24x24/devices ; rm -rf gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/24x24/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-transmit-receive.png gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-visiting.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_repeat.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf media-playlist-repeat.png stock_repeat.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_dialog-warning.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-warning.png stock_dialog-warning.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_lock-ok.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf security-high.png stock_lock-ok.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_mail-unread.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf mail-unread.png stock_mail-unread.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-password.png gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_lock-open.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf security-low.png stock_lock-open.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-missing-image.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf image-missing.png gtk-missing-image.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf appointment-missed.png stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf folder_open.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-open.png folder_open.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf connect_no.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-offline.png connect_no.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-directory-visiting.icon )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-visiting.icon gnome-fs-directory-visiting.icon )
( cd usr/share/icons/gnome/24x24/status ; rm -rf messagebox_info.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-information.png messagebox_info.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf edittrash.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png edittrash.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-cloudy.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-overcast.png stock_weather-cloudy.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-night-clear.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-clear-night.png stock_weather-night-clear.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-few-clouds.png stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-dialog-warning.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-warning.png gtk-dialog-warning.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-dialog-question.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-question.png gtk-dialog-question.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume-med.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-medium.png stock_volume-med.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-error.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-error.png gnome-netstatus-error.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_attach.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf mail-attachment.png stock_attach.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf xfce-trash_full.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png xfce-trash_full.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf nm-device-wired.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-idle.png nm-device-wired.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-transmit.png gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_appointment-reminder.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf appointment-soon.png stock_appointment-reminder.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_lock.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf security-medium.png stock_lock.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-drag-accept.png gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-wireless-encrypted.png gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf info.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-information.png info.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-receive.png gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf trashcan_full.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png trashcan_full.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf nm-no-connection.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-offline.png nm-no-connection.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf connect_creating.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-transmit-receive.png connect_creating.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-idle.png gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-high.png stock_volume.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-dialog-error.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-error.png gtk-dialog-error.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf error.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-error.png error.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_mail-open.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf mail-read.png stock_mail-open.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf image-loading.png gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_trash_full.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png stock_trash_full.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-showers.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-showers.png stock_weather-showers.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-few-clouds-night.png stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_dialog-error.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-error.png stock_dialog-error.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-fog.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-fog.png stock_weather-fog.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-storm.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-storm.png stock_weather-storm.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume-0.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-low.png stock_volume-0.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-offline.png gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf connect_established.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-idle.png connect_established.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf nm-adhoc.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-idle.png nm-adhoc.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-sunny.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-clear.png stock_weather-sunny.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-directory-accept.icon )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-drag-accept.icon gnome-fs-directory-accept.icon )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gtk-dialog-info.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-information.png gtk-dialog-info.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_lock-broken.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf security-low.png stock_lock-broken.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_dialog-info.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-information.png stock_dialog-info.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf important.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-warning.png important.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf user-trash-full.png gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume-min.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-low.png stock_volume-min.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_mail-replied.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf mail-replied.png stock_mail-replied.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_open.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf folder-open.png stock_open.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf messagebox_critical.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-error.png messagebox_critical.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_weather-snow.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-snow.png stock_weather-snow.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_shuffle.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf media-playlist-shuffle.png stock_shuffle.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf messagebox_warning.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-warning.png messagebox_warning.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume-max.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-high.png stock_volume-max.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_volume-mute.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf audio-volume-muted.png stock_volume-mute.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf nm-device-wireless.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf network-idle.png nm-device-wireless.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf sunny.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf weather-clear.png sunny.png )
( cd usr/share/icons/gnome/24x24/status ; rm -rf stock_dialog-question.png )
( cd usr/share/icons/gnome/24x24/status ; ln -sf dialog-question.png stock_dialog-question.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-character-map.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-character-map.png gnome-character-map.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-settings-font.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-font.png gnome-settings-font.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf style.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-theme.png style.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-help.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png gnome-help.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xscreensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-screensaver.png xscreensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf screensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-screensaver.png screensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf locale.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-locale.png locale.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xfce4-backdrop.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-wallpaper.png xfce4-backdrop.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf openterm.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-terminal.png openterm.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf ksysguard.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-system-monitor.png ksysguard.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xfce4-mixer.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png xfce4-mixer.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-mixer.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png gnome-mixer.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf config-language.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-locale.png config-language.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf config-users.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-users.png config-users.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kcalc.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-calculator.png kcalc.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf wallpaper.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-wallpaper.png wallpaper.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-settings-background.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-wallpaper.png gnome-settings-background.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf accessibility-directory.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-accessibility.png accessibility-directory.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-terminal.png gnome-terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf update-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-software-update.png update-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf stock_help.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png stock_help.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-accessibility.png gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf key_bindings.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png key_bindings.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kcmkwm.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-system-windows.png kcmkwm.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xfce-terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-terminal.png xfce-terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf volume-knob.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png volume-knob.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gucharmap.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-character-map.png gucharmap.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf multimedia.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png multimedia.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-system-monitor.png gnome-monitor.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kuser.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-users.png kuser.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf redhat-filemanager.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-file-manager.png redhat-filemanager.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf zen-icon.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-software-update.png zen-icon.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-settings-theme.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-theme.png gnome-settings-theme.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kedit.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-text-editor.png kedit.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf help.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png help.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xfce-filemanager.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-file-manager.png xfce-filemanager.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf calc.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-calculator.png calc.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kcharselect.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-character-map.png kcharselect.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf arts.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png arts.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-remote-desktop.png gnome-remote-desktop.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gtk-help.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png gtk-help.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf background.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-wallpaper.png background.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf file-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-file-manager.png file-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-window-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-system-windows.png gnome-window-manager.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf access.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-accessibility.png access.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kfm.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-file-manager.png kfm.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kscreensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-screensaver.png kscreensaver.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf khelpcenter.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png khelpcenter.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf xfwm4.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-system-windows.png xfwm4.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kwin.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-system-windows.png kwin.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf gnome-calculator.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-calculator.png gnome-calculator.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf system-config-users.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf system-users.png system-config-users.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-terminal.png terminal.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf susehelpcenter.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf help-browser.png susehelpcenter.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf krfb.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-remote-desktop.png krfb.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf text-editor.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf accessories-text-editor.png text-editor.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf kcmsound.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf multimedia-volume-control.png kcmsound.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf konsole.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf utilities-terminal.png konsole.png )
( cd usr/share/icons/gnome/24x24/apps ; rm -rf fonts.png )
( cd usr/share/icons/gnome/24x24/apps ; ln -sf preferences-desktop-font.png fonts.png )
( cd usr/share/icons/gnome/24x24/animations ; rm -rf gnome-spinner-rest.png )
( cd usr/share/icons/gnome/24x24/animations ; ln -sf process-idle.png gnome-spinner-rest.png )
( cd usr/share/icons/gnome/24x24/animations ; rm -rf gnome-spinner.png )
( cd usr/share/icons/gnome/24x24/animations ; ln -sf process-working.png gnome-spinner.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-8.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-plain.png stock_smiley-8.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-15.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-cool.png stock_smiley-15.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-1.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-smile.png stock_smiley-1.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-11.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-crying.png stock_smiley-11.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-10.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-raspberry.png stock_smiley-10.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-2.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-smile.png stock_smiley-2.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-13.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-kiss.png stock_smiley-13.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-4.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-sad.png stock_smiley-4.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-5.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-surprise.png stock_smiley-5.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-3.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-wink.png stock_smiley-3.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-18.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-angel.png stock_smiley-18.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-7.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-smile.png stock_smiley-7.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-6.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-smile-big.png stock_smiley-6.png )
( cd usr/share/icons/gnome/24x24/emotes ; rm -rf stock_smiley-22.png )
( cd usr/share/icons/gnome/24x24/emotes ; ln -sf face-monkey.png stock_smiley-22.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-server.png gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf novell-button.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf start-here.png novell-button.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf redhat-network-server.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-server.png redhat-network-server.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gtk-directory.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.png gtk-directory.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf desktop.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-desktop.png desktop.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-fs-ssh.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf distributor-logo.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf start-here.png distributor-logo.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-workgroup.png gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf trashcan_empty.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-trash.png trashcan_empty.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-saved-search.png application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf xfce-trash_empty.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-trash.png xfce-trash_empty.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-fs-ftp.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gtk-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.icon gtk-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-stock-trash.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-trash.png gnome-stock-trash.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf emptytrash.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-trash.png emptytrash.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gtk-network.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-workgroup.png gtk-network.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf stock_folder.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.png stock_folder.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-main-menu.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf start-here.png gnome-main-menu.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-server.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-server.png gnome-fs-server.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-directory.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.png gnome-fs-directory.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf folder_home.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-home.png folder_home.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-share.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-fs-share.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf stock_folder.icon )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.icon stock_folder.icon )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-trash.png gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf network.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png network.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf inode-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.icon inode-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-network.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-workgroup.png gnome-fs-network.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-home.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-home.png gnome-fs-home.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-desktop.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf user-desktop.png gnome-fs-desktop.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-server.png gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-fs-nfs.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf network_local.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-workgroup.png network_local.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf inode-directory.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.png inode-directory.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf server.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf network-server.png server.png )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder.icon gnome-fs-directory.icon )
( cd usr/share/icons/gnome/24x24/places ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/gnome/24x24/places ; ln -sf folder-remote.png gnome-fs-smb.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf viewmag-.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-out.png viewmag-.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_save.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save.png stock_save.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-run.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-run.png gnome-run.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf editdelete.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-delete.png editdelete.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf zoom-best-fit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-fit-best.png zoom-best-fit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_pause.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-pause.png player_pause.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_end.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-forward.png player_end.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-last.png gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_right.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-next.png stock_right.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_up.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-up.png stock_up.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_spellcheck.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf tools-check-spelling.png stock_spellcheck.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf editcopy.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-copy.png editcopy.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_delete.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-delete.png stock_delete.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_home.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-home.png stock_home.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf kfm_home.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-home.png kfm_home.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-cancel.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf process-stop.png gtk-cancel.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_right.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-right.png stock_text_right.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-zoom-out.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-out.png gtk-zoom-out.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_replyall.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-reply-all.png mail_replyall.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-dir.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf folder-new.png stock_new-dir.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf rightjust.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-right.png rightjust.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-new.png gtk-new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-backward.png gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_undo.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-undo.png stock_undo.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-about.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf help-about.png gtk-about.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-indent-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-more.png gtk-indent-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-close.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf window-close.png gtk-close.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-sort-descending.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-sort-descending.png gtk-sort-descending.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_forward.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-forward.png mail_forward.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf editcut.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-cut.png editcut.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-select-all.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-select-all.png gtk-select-all.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf process-stop.png gtk-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_save-as.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save-as.png stock_save-as.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-undo-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-undo.png gtk-undo-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_zoom-1.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-original.png stock_zoom-1.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-forward.png stock_media-fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-message-new.png mail_new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-top.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-top.png gtk-goto-top.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_search.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find.png stock_search.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf lock.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-lock-screen.png lock.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-justify-right.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-right.png gtk-justify-right.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-next.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-forward.png stock_media-next.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-less.png gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-start.png gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_center.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-center.png stock_text_center.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_add-bookmark.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf bookmark-new.png stock_add-bookmark.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-reply-all.png stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-record.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-record.png gtk-media-record.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf tab_new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf tab-new.png tab_new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-justify-center.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-center.png gtk-justify-center.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf kfind.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-search.png kfind.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-bcard.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf contact-new.png stock_new-bcard.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf viewmag+.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-in.png viewmag+.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf reload_page.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png reload_page.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-underline.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-underline.png gtk-underline.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf folder_new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf folder-new.png folder_new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-revert.png gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-clear.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-clear.png gtk-clear.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf process-stop.png stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-next.png gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_spam.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-mark-junk.png stock_spam.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-forward.png gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-bottom.png gtk-goto-bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-zoom-100.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-original.png gtk-zoom-100.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf fileopen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-open.png fileopen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-zoom-fit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-fit-best.png gtk-zoom-fit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_send.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-send.png mail_send.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf filesaveas.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save-as.png filesaveas.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf redhat-home.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-home.png redhat-home.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-forward.png gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-bottom.png stock_bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-jump.png gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-stop.png gtk-media-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf previous.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-previous.png previous.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-fullscreen.png gtk-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-print.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print.png gtk-print.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_zoom-in.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-in.png stock_zoom-in.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_redo.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-redo.png stock_redo.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_first.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-first.png stock_first.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-cut.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-cut.png gtk-cut.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-shutdown.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-shutdown.png gnome-shutdown.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf reload3.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png reload3.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-prev.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-backward.png stock_media-prev.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-revert.png gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-print-preview.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print-preview.png gtk-print-preview.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf bookmark_add.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf bookmark-new.png bookmark_add.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-bottom.png bottom.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_properties.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-properties.png stock_properties.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-stop.png player_stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_rew.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-backward.png player_rew.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf viewmagfit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-fit-best.png viewmagfit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf process-stop.png stock_stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-reply-sender.png gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_select-all.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-select-all.png stock_select-all.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_top.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-top.png stock_top.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-more.png gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf exit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf application-exit.png exit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-italic.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-italic.png gtk-italic.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf viewmag1.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-original.png viewmag1.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf xfce-system-exit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf application-exit.png xfce-system-exit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf revert.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-revert.png revert.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text-strikethrough.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-strikethrough.png stock_text-strikethrough.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-send.png gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-find-and-replace.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find-replace.png gtk-find-and-replace.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf bookmark-new.png stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-quit.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf application-exit.png gtk-quit.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-previous.png gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-reply.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-reply-sender.png stock_mail-reply.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-zoom-in.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-in.png gtk-zoom-in.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf window_nofullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-restore.png window_nofullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-jump.png gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf redo.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-redo.png redo.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf text_strike.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-strikethrough.png text_strike.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_left.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-left.png stock_text_left.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_about.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf help-about.png stock_about.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf reload_all_tabs.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png reload_all_tabs.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_zoom-out.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-out.png stock_zoom-out.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_reply.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-reply-sender.png mail_reply.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf editpaste.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-paste.png editpaste.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_indent.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-more.png stock_text_indent.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-lock-screen.png gnome-lockscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_print-setup.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-page-setup.png stock_print-setup.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-down.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-down.png gtk-go-down.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_italic.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-italic.png stock_text_italic.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf xfce-system-lock.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-lock-screen.png xfce-system-lock.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf add.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf list-add.png add.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-redo-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-redo.png gtk-redo-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-forward.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-forward.png stock_mail-forward.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_last.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-last.png stock_last.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf bookmarks_list_add.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf bookmark-new.png bookmarks_list_add.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_underlined.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-underline.png stock_text_underlined.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-last.png gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf filesave.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save.png filesave.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-forward.png gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-justify-fill.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-fill.png gtk-justify-fill.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-indent-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-less.png gtk-indent-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf down.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-down.png down.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-send.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-send.png stock_mail-send.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-more.png gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_close.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf window-close.png stock_close.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf search.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-search.png search.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_zoom-page.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf zoom-fit-best.png stock_zoom-page.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-compose.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-message-new.png stock_mail-compose.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf next.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-next.png next.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-spell-check.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf tools-check-spelling.png gtk-spell-check.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-searchtool.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-search.png gnome-searchtool.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-justify-left.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-left.png gtk-justify-left.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf remove.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf list-remove.png remove.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-up.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-up.png gtk-go-up.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-find.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find.png gtk-find.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-less.png gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-delete.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-delete.png gtk-delete.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-remove.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf list-remove.png gtk-remove.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-pause.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-pause.png gtk-media-pause.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-rec.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-record.png stock_media-rec.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-forward.png gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-restore.png gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf text_italic.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-italic.png text_italic.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-appointment.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf appointment-new.png stock_new-appointment.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-message-new.png gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-bold.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-bold.png gtk-bold.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-home.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-home.png gtk-home.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-tab.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf tab-new.png stock_new-tab.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_paste.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-paste.png stock_paste.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_record.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-record.png player_record.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_refresh.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png stock_refresh.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf editclear.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-clear.png editclear.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_down.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-down.png stock_down.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-refresh.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png gtk-refresh.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-forward.png gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf text_under.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-underline.png text_under.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf filenew.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-new.png filenew.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-address-book.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf address-book-new.png stock_new-address-book.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_print-preview.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print-preview.png stock_print-preview.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf filequickprint.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print-preview.png filequickprint.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-backward.png gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_search-and-replace.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find-replace.png stock_search-and-replace.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf window_fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-fullscreen.png window_fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf forward.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-next.png forward.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-paste.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-paste.png gtk-paste.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf leftjust.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-left.png leftjust.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-copy.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-copy.png gtk-copy.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf up.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-up.png up.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-previous.png gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-forward.png player_fwd.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf text_bold.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-bold.png text_bold.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-pause.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-pause.png stock_media-pause.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-save-as.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save-as.png gtk-save-as.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf window_new.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf window-new.png window_new.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gohome.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-home.png gohome.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-execute.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-run.png gtk-execute.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-first.png gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-restore.png stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gnome-logout.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf system-log-out.png gnome-logout.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_justify.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-fill.png stock_text_justify.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf top.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-top.png top.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-fullscreen.png stock_fullscreen.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-strikethrough.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-strikethrough.png gtk-strikethrough.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-window.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf window-new.png stock_new-window.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_play.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-start.png player_play.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-next.png gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf filefind.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find.png filefind.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf back.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-previous.png back.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf undo.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-undo.png undo.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_new-text.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-new.png stock_new-text.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf reload.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-refresh.png reload.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf mail_spam.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-mark-junk.png mail_spam.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_start.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-backward.png player_start.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf player_eject.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-eject.png player_eject.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-backward.png gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf fileprint.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print.png fileprint.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_left.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-previous.png stock_left.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-first.png gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_cut.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-cut.png stock_cut.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf find.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-find.png find.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf finish.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-last.png finish.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-play.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-start.png stock_media-play.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_unindent.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-indent-less.png stock_text_unindent.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-open.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-open.png gtk-open.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_file-properites.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-properties.png stock_file-properites.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf start.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf go-first.png start.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-sort-ascending.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf view-sort-ascending.png gtk-sort-ascending.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-save.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-save.png gtk-save.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf centrejust.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-justify-center.png centrejust.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_mail-send-receive.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf mail-send-receive.png stock_mail-send-receive.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_print.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-print.png stock_print.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-skip-backward.png gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-properties.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf document-properties.png gtk-properties.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-playback-stop.png stock_media-stop.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_copy.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf edit-copy.png stock_copy.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_media-rew.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf media-seek-backward.png stock_media-rew.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf stock_text_bold.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf format-text-bold.png stock_text_bold.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf gtk-add.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf list-add.png gtk-add.png )
( cd usr/share/icons/gnome/24x24/actions ; rm -rf appointment.png )
( cd usr/share/icons/gnome/24x24/actions ; ln -sf appointment-new.png appointment.png )
( cd usr/share/icons/gnome/8x8/emblems ; rm -rf emblem-noread.png )
( cd usr/share/icons/gnome/8x8/emblems ; ln -sf emblem-unreadable.png emblem-noread.png )
( cd usr/share/icons/gnome/8x8/emblems ; rm -rf emblem-nowrite.png )
( cd usr/share/icons/gnome/8x8/emblems ; ln -sf emblem-readonly.png emblem-nowrite.png )
( cd usr/share/icons/gnome/16x16/emblems ; rm -rf emblem-noread.png )
( cd usr/share/icons/gnome/16x16/emblems ; ln -sf emblem-unreadable.png emblem-noread.png )
( cd usr/share/icons/gnome/16x16/emblems ; rm -rf stock_mail-priority-high.png )
( cd usr/share/icons/gnome/16x16/emblems ; ln -sf emblem-important.png stock_mail-priority-high.png )
( cd usr/share/icons/gnome/16x16/emblems ; rm -rf emblem-nowrite.png )
( cd usr/share/icons/gnome/16x16/emblems ; ln -sf emblem-readonly.png emblem-nowrite.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png gnome-mime-text.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf html.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png html.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf image-x-generic.png image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf www.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png www.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf stock_script.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png stock_script.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-address-book.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf document.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png document.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf rpm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png rpm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf vcard.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-address-book.png vcard.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf image-x-generic.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-fs-regular.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-preview.png gnome-fs-regular.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png gnome-mime-text-html.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf zip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png zip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf exec.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-x-executable.png exec.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf shellscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png shellscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf txt2.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png txt2.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf folder_tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png folder_tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-fs-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-x-executable.png gnome-fs-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-audio.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf audio-x-generic.png gnome-mime-audio.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf package.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png package.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf empty.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png empty.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf unknown.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png unknown.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf sound.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf audio-x-generic.png sound.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-package.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf stock_certificate.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-certificate.png stock_certificate.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf font_bitmap.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png font_bitmap.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf audio-x-generic.png gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png spreadsheet.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf contents2.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-address-book.png contents2.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf mime_ascii.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png mime_ascii.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf package_editors.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png package_editors.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf misc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png misc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf template_source.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic-template.png template_source.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf wordprocessing.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png wordprocessing.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf image-x-generic.png gnome-mime-image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf kpresenter_kpr.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png kpresenter_kpr.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf stock_addressbook.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-address-book.png stock_addressbook.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf stock_calendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-calendar.png stock_calendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf font.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png font.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf binary.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-x-executable.png binary.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf vcalendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-calendar.png vcalendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-html.png gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-calendar.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf ascii.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png ascii.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf plan.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-calendar.png plan.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf tgz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png tgz.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf package_wordprocessing.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png package_wordprocessing.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf txt.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-generic.png txt.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf video.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png video.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf font_truetype.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png font_truetype.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf font_type1.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf font-x-generic.png font_type1.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gtk-file.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf text-x-preview.png gtk-file.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf x-office-document.png gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf gnome-mime-video.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf video-x-generic.png gnome-mime-video.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; rm -rf deb.png )
( cd usr/share/icons/gnome/16x16/mimetypes ; ln -sf package-x-generic.png deb.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-multimedia.png gnome-multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-globe.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-internet.png gnome-globe.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-applications.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-office.png gnome-applications.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce4-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png xfce4-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-sound_video.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-multimedia.png redhat-sound_video.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-system.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-system.png gnome-system.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-control-center.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png gnome-control-center.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-multimedia.png xfce-multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-system_tools.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-system.png redhat-system_tools.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-preferences.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png redhat-preferences.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-graphics.png xfce-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png gnome-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-joystick.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-games.png gnome-joystick.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-office.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-office.png xfce-office.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-internet.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-internet.png redhat-internet.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-system-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-system.png xfce-system-settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_system.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-system.png package_system.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-internet.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-internet.png xfce-internet.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-office.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-office.png redhat-office.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-system.png package_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-programming.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-development.png redhat-programming.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_network.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-internet.png package_network.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_games.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-games.png package_games.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-graphics.png gnome-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_development.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-development.png package_development.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-games.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-games.png xfce-games.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_utilities.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-accessories.png package_utilities.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-graphics.png redhat-graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-util.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-accessories.png gnome-util.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf kcontrol.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png kcontrol.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-accessories.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-accessories.png redhat-accessories.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-multimedia.png package_multimedia.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf stock_internet.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-internet.png stock_internet.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-games.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-games.png redhat-games.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf redhat-system_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-system.png redhat-system_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-other.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-other.png gnome-other.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf input_devices_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop-peripherals.png input_devices_settings.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gtk-preferences.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf preferences-desktop.png gtk-preferences.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_office.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-office.png package_office.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf gnome-devel.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-development.png gnome-devel.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf package_graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-graphics.png package_graphics.png )
( cd usr/share/icons/gnome/16x16/categories ; rm -rf xfce-utils.png )
( cd usr/share/icons/gnome/16x16/categories ; ln -sf applications-accessories.png xfce-utils.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf printer1.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png printer1.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf cdwriter_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png cdwriter_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf stock_printers.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png stock_printers.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-floppy.png gnome-dev-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-flash.png gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-flash.png gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-computer.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf computer.png gnome-dev-computer.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-optical.png gnome-dev-dvd.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gtk-harddisk.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png gtk-harddisk.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf stock_mic.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf audio-input-microphone.png stock_mic.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf xfce4-keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-keyboard.png xfce4-keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-mouse.png yast_mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf network-wired.png gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_idetude.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png yast_idetude.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf harddrive.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png harddrive.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_soundcard.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf audio-card.png yast_soundcard.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf ipod_mount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf multimedia-player.png ipod_mount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-fs-client.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf computer.png gnome-fs-client.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf kxkb.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-keyboard.png kxkb.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-keyboard.png keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf drive-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-optical.png drive-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-zip.png gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf usbpendrive_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-removable-media.png usbpendrive_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf cdrom_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png cdrom_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf display.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf video-display.png display.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-removable-media.png gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-battery.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf battery.png gnome-dev-battery.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-mouse.png mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf joystick.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-gaming.png joystick.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf 3floppy_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-floppy.png 3floppy_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-removable-media.png gnome-dev-removable.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gtk-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gtk-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf dvd_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png dvd_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-mouse.png gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf media-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png media-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-optical.png gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-keyboard.png gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_joystick.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-gaming.png yast_joystick.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-ipod.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf multimedia-player.png gnome-dev-ipod.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf xfce4-display.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf video-display.png xfce4-display.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf network-wireless.png gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf xfce-printer.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png xfce-printer.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf system-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-floppy.png system-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf printer-remote.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png printer-remote.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-flash.png gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-stock-mic.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf audio-input-microphone.png gnome-stock-mic.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf camera_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf camera-photo.png camera_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-modem.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf modem.png gnome-modem.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf camera.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf camera-photo.png camera.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-printer.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png gnome-dev-printer.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-flash.png gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf stock_cell-phone.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf phone.png stock_cell-phone.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf xfce4-mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-mouse.png xfce4-mouse.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf system.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf computer.png system.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gtk-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-floppy.png gtk-floppy.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_printer.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png yast_printer.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf input-mouse.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf hdd_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png hdd_unmount.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf printmgr.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png printmgr.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf yast_HD.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png yast_HD.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-removable-media.png gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf kjobviewer.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf printer.png kjobviewer.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf chardevice.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf video-display.png chardevice.png )
( cd usr/share/icons/gnome/16x16/devices ; rm -rf gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/16x16/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-transmit-receive.png gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf folder-visiting.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_repeat.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf media-playlist-repeat.png stock_repeat.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_dialog-warning.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-warning.png stock_dialog-warning.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_lock-ok.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf security-high.png stock_lock-ok.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_mail-unread.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf mail-unread.png stock_mail-unread.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-password.png gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_lock-open.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf security-low.png stock_lock-open.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-missing-image.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf image-missing.png gtk-missing-image.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf appointment-missed.png stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf folder_open.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf folder-open.png folder_open.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf connect_no.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-offline.png connect_no.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf messagebox_info.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-information.png messagebox_info.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf edittrash.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png edittrash.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-cloudy.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-overcast.png stock_weather-cloudy.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-night-clear.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-clear-night.png stock_weather-night-clear.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-few-clouds.png stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-dialog-warning.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-warning.png gtk-dialog-warning.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-dialog-question.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-question.png gtk-dialog-question.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume-med.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-medium.png stock_volume-med.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-error.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-error.png gnome-netstatus-error.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_attach.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf mail-attachment.png stock_attach.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf xfce-trash_full.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png xfce-trash_full.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf nm-device-wired.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-idle.png nm-device-wired.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-transmit.png gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_appointment-reminder.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf appointment-soon.png stock_appointment-reminder.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_lock.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf security-medium.png stock_lock.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf folder-drag-accept.png gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-wireless-encrypted.png gnome-dev-wavelan-encrypted.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf info.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-information.png info.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-receive.png gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf trashcan_full.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png trashcan_full.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf nm-no-connection.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-offline.png nm-no-connection.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf connect_creating.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-transmit-receive.png connect_creating.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-idle.png gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-high.png stock_volume.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-dialog-error.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-error.png gtk-dialog-error.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf error.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-error.png error.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_mail-open.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf mail-read.png stock_mail-open.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf image-loading.png gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_trash_full.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png stock_trash_full.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-showers.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-showers.png stock_weather-showers.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-few-clouds-night.png stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_dialog-error.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-error.png stock_dialog-error.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-fog.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-fog.png stock_weather-fog.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-storm.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-storm.png stock_weather-storm.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume-0.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-low.png stock_volume-0.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-offline.png gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf connect_established.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-idle.png connect_established.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf nm-adhoc.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-idle.png nm-adhoc.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-sunny.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-clear.png stock_weather-sunny.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gtk-dialog-info.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-information.png gtk-dialog-info.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_lock-broken.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf security-low.png stock_lock-broken.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_dialog-info.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-information.png stock_dialog-info.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf important.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-warning.png important.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf user-trash-full.png gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume-min.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-low.png stock_volume-min.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_mail-replied.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf mail-replied.png stock_mail-replied.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_open.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf folder-open.png stock_open.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf messagebox_critical.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-error.png messagebox_critical.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_weather-snow.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-snow.png stock_weather-snow.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_shuffle.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf media-playlist-shuffle.png stock_shuffle.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf messagebox_warning.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-warning.png messagebox_warning.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume-max.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-high.png stock_volume-max.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_volume-mute.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf audio-volume-muted.png stock_volume-mute.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf nm-device-wireless.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf network-idle.png nm-device-wireless.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf sunny.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf weather-clear.png sunny.png )
( cd usr/share/icons/gnome/16x16/status ; rm -rf stock_dialog-question.png )
( cd usr/share/icons/gnome/16x16/status ; ln -sf dialog-question.png stock_dialog-question.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-character-map.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-character-map.png gnome-character-map.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-settings-font.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-font.png gnome-settings-font.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf style.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-theme.png style.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-help.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png gnome-help.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xscreensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-screensaver.png xscreensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf screensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-screensaver.png screensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf locale.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-locale.png locale.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xfce4-backdrop.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-wallpaper.png xfce4-backdrop.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf openterm.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-terminal.png openterm.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf ksysguard.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-system-monitor.png ksysguard.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xfce4-mixer.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png xfce4-mixer.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-mixer.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png gnome-mixer.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf config-language.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-locale.png config-language.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf config-users.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-users.png config-users.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kcalc.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-calculator.png kcalc.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf wallpaper.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-wallpaper.png wallpaper.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-settings-background.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-wallpaper.png gnome-settings-background.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf accessibility-directory.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-accessibility.png accessibility-directory.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-terminal.png gnome-terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf update-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-software-update.png update-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf stock_help.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png stock_help.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-accessibility.png gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf key_bindings.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png key_bindings.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kcmkwm.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-system-windows.png kcmkwm.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xfce-terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-terminal.png xfce-terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf volume-knob.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png volume-knob.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gucharmap.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-character-map.png gucharmap.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf multimedia.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png multimedia.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-system-monitor.png gnome-monitor.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kuser.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-users.png kuser.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf redhat-filemanager.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-file-manager.png redhat-filemanager.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf zen-icon.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-software-update.png zen-icon.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-settings-theme.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-theme.png gnome-settings-theme.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kedit.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-text-editor.png kedit.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf help.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png help.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xfce-filemanager.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-file-manager.png xfce-filemanager.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf calc.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-calculator.png calc.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kcharselect.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-character-map.png kcharselect.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf arts.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png arts.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-remote-desktop.png gnome-remote-desktop.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gtk-help.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png gtk-help.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf background.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-wallpaper.png background.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf file-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-file-manager.png file-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-window-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-system-windows.png gnome-window-manager.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf access.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-accessibility.png access.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kfm.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-file-manager.png kfm.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kscreensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-screensaver.png kscreensaver.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf khelpcenter.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png khelpcenter.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf xfwm4.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-system-windows.png xfwm4.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kwin.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-system-windows.png kwin.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf gnome-calculator.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-calculator.png gnome-calculator.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf system-config-users.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf system-users.png system-config-users.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-terminal.png terminal.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf susehelpcenter.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf help-browser.png susehelpcenter.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf krfb.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-remote-desktop.png krfb.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf text-editor.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf accessories-text-editor.png text-editor.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf kcmsound.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf multimedia-volume-control.png kcmsound.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf konsole.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf utilities-terminal.png konsole.png )
( cd usr/share/icons/gnome/16x16/apps ; rm -rf fonts.png )
( cd usr/share/icons/gnome/16x16/apps ; ln -sf preferences-desktop-font.png fonts.png )
( cd usr/share/icons/gnome/16x16/animations ; rm -rf gnome-spinner-rest.png )
( cd usr/share/icons/gnome/16x16/animations ; ln -sf process-idle.png gnome-spinner-rest.png )
( cd usr/share/icons/gnome/16x16/animations ; rm -rf gnome-spinner.png )
( cd usr/share/icons/gnome/16x16/animations ; ln -sf process-working.png gnome-spinner.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-8.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-plain.png stock_smiley-8.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-15.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-cool.png stock_smiley-15.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-1.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-smile.png stock_smiley-1.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-11.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-crying.png stock_smiley-11.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-10.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-raspberry.png stock_smiley-10.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-2.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-smile.png stock_smiley-2.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-13.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-kiss.png stock_smiley-13.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-4.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-sad.png stock_smiley-4.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-5.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-surprise.png stock_smiley-5.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-3.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-wink.png stock_smiley-3.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-18.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-angel.png stock_smiley-18.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-7.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-smile.png stock_smiley-7.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-6.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-smile-big.png stock_smiley-6.png )
( cd usr/share/icons/gnome/16x16/emotes ; rm -rf stock_smiley-22.png )
( cd usr/share/icons/gnome/16x16/emotes ; ln -sf face-monkey.png stock_smiley-22.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-server.png gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf novell-button.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf start-here.png novell-button.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf redhat-network-server.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-server.png redhat-network-server.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gtk-directory.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.png gtk-directory.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf desktop.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-desktop.png desktop.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-fs-ssh.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf distributor-logo.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf start-here.png distributor-logo.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-workgroup.png gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf trashcan_empty.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-trash.png trashcan_empty.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-saved-search.png application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf xfce-trash_empty.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-trash.png xfce-trash_empty.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-fs-ftp.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gtk-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.icon gtk-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-stock-trash.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-trash.png gnome-stock-trash.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf emptytrash.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-trash.png emptytrash.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gtk-network.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-workgroup.png gtk-network.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf stock_folder.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.png stock_folder.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-main-menu.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf start-here.png gnome-main-menu.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-server.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-server.png gnome-fs-server.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-directory.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.png gnome-fs-directory.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf folder_home.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-home.png folder_home.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-share.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-fs-share.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf stock_folder.icon )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.icon stock_folder.icon )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-trash.png gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf network.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png network.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf inode-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.icon inode-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-network.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-workgroup.png gnome-fs-network.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-home.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-home.png gnome-fs-home.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-desktop.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf user-desktop.png gnome-fs-desktop.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-server.png gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-fs-nfs.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf network_local.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-workgroup.png network_local.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf inode-directory.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.png inode-directory.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf server.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf network-server.png server.png )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder.icon gnome-fs-directory.icon )
( cd usr/share/icons/gnome/16x16/places ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/gnome/16x16/places ; ln -sf folder-remote.png gnome-fs-smb.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf viewmag-.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-out.png viewmag-.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_save.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save.png stock_save.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-run.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-run.png gnome-run.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf editdelete.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-delete.png editdelete.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf zoom-best-fit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-fit-best.png zoom-best-fit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_pause.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-pause.png player_pause.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_end.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-forward.png player_end.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-last.png gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_right.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-next.png stock_right.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_up.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-up.png stock_up.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_spellcheck.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf tools-check-spelling.png stock_spellcheck.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf editcopy.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-copy.png editcopy.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_delete.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-delete.png stock_delete.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_home.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-home.png stock_home.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf kfm_home.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-home.png kfm_home.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-cancel.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf process-stop.png gtk-cancel.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_right.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-right.png stock_text_right.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-zoom-out.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-out.png gtk-zoom-out.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_replyall.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-reply-all.png mail_replyall.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-dir.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf folder-new.png stock_new-dir.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf rightjust.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-right.png rightjust.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-new.png gtk-new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-backward.png gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_undo.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-undo.png stock_undo.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-about.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf help-about.png gtk-about.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-indent-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-more.png gtk-indent-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-close.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf window-close.png gtk-close.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-sort-descending.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-sort-descending.png gtk-sort-descending.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_forward.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-forward.png mail_forward.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf editcut.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-cut.png editcut.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-select-all.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-select-all.png gtk-select-all.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf process-stop.png gtk-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_save-as.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save-as.png stock_save-as.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-undo-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-undo.png gtk-undo-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_zoom-1.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-original.png stock_zoom-1.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-forward.png stock_media-fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-message-new.png mail_new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-top.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-top.png gtk-goto-top.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_search.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find.png stock_search.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf lock.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-lock-screen.png lock.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-justify-right.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-right.png gtk-justify-right.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-next.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-forward.png stock_media-next.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-less.png gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-start.png gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_center.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-center.png stock_text_center.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_add-bookmark.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf bookmark-new.png stock_add-bookmark.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-reply-all.png stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-record.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-record.png gtk-media-record.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf tab_new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf tab-new.png tab_new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-justify-center.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-center.png gtk-justify-center.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf kfind.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-search.png kfind.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-bcard.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf contact-new.png stock_new-bcard.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf viewmag+.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-in.png viewmag+.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf reload_page.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png reload_page.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-underline.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-underline.png gtk-underline.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf folder_new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf folder-new.png folder_new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-revert.png gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-clear.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-clear.png gtk-clear.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf process-stop.png stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-next.png gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_spam.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-mark-junk.png stock_spam.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-forward.png gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-bottom.png gtk-goto-bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-zoom-100.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-original.png gtk-zoom-100.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf fileopen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-open.png fileopen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-zoom-fit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-fit-best.png gtk-zoom-fit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_send.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-send.png mail_send.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf filesaveas.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save-as.png filesaveas.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf redhat-home.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-home.png redhat-home.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-forward.png gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-bottom.png stock_bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-jump.png gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-stop.png gtk-media-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf previous.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-previous.png previous.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-fullscreen.png gtk-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-print.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print.png gtk-print.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_zoom-in.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-in.png stock_zoom-in.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_redo.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-redo.png stock_redo.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_first.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-first.png stock_first.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-cut.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-cut.png gtk-cut.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-shutdown.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-shutdown.png gnome-shutdown.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf reload3.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png reload3.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-prev.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-backward.png stock_media-prev.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-revert.png gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-print-preview.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print-preview.png gtk-print-preview.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf bookmark_add.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf bookmark-new.png bookmark_add.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-bottom.png bottom.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_properties.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-properties.png stock_properties.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-stop.png player_stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_rew.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-backward.png player_rew.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf viewmagfit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-fit-best.png viewmagfit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf process-stop.png stock_stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-reply-sender.png gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_select-all.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-select-all.png stock_select-all.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_top.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-top.png stock_top.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-more.png gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf exit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf application-exit.png exit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-italic.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-italic.png gtk-italic.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf viewmag1.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-original.png viewmag1.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf xfce-system-exit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf application-exit.png xfce-system-exit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf revert.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-revert.png revert.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text-strikethrough.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-strikethrough.png stock_text-strikethrough.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-send.png gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-find-and-replace.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find-replace.png gtk-find-and-replace.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf bookmark-new.png stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-quit.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf application-exit.png gtk-quit.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-previous.png gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-reply.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-reply-sender.png stock_mail-reply.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-zoom-in.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-in.png gtk-zoom-in.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf window_nofullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-restore.png window_nofullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-jump.png gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf redo.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-redo.png redo.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf text_strike.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-strikethrough.png text_strike.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_left.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-left.png stock_text_left.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_about.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf help-about.png stock_about.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf reload_all_tabs.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png reload_all_tabs.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_zoom-out.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-out.png stock_zoom-out.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_reply.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-reply-sender.png mail_reply.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf editpaste.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-paste.png editpaste.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_indent.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-more.png stock_text_indent.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-lock-screen.png gnome-lockscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_print-setup.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-page-setup.png stock_print-setup.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-down.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-down.png gtk-go-down.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_italic.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-italic.png stock_text_italic.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf xfce-system-lock.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-lock-screen.png xfce-system-lock.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf add.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf list-add.png add.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-redo-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-redo.png gtk-redo-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-forward.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-forward.png stock_mail-forward.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_last.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-last.png stock_last.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf bookmarks_list_add.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf bookmark-new.png bookmarks_list_add.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_underlined.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-underline.png stock_text_underlined.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-last.png gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf filesave.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save.png filesave.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-forward.png gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-justify-fill.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-fill.png gtk-justify-fill.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-indent-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-less.png gtk-indent-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf down.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-down.png down.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-send.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-send.png stock_mail-send.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-more.png gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_close.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf window-close.png stock_close.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf search.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-search.png search.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_zoom-page.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf zoom-fit-best.png stock_zoom-page.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-compose.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-message-new.png stock_mail-compose.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf next.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-next.png next.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-spell-check.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf tools-check-spelling.png gtk-spell-check.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-searchtool.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-search.png gnome-searchtool.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-justify-left.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-left.png gtk-justify-left.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf remove.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf list-remove.png remove.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-up.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-up.png gtk-go-up.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-find.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find.png gtk-find.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-less.png gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-delete.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-delete.png gtk-delete.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-remove.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf list-remove.png gtk-remove.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-pause.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-pause.png gtk-media-pause.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-rec.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-record.png stock_media-rec.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-forward.png gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-restore.png gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf text_italic.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-italic.png text_italic.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-appointment.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf appointment-new.png stock_new-appointment.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-message-new.png gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-bold.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-bold.png gtk-bold.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-home.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-home.png gtk-home.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-tab.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf tab-new.png stock_new-tab.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_paste.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-paste.png stock_paste.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_record.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-record.png player_record.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_refresh.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png stock_refresh.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf editclear.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-clear.png editclear.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_down.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-down.png stock_down.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-refresh.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png gtk-refresh.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-forward.png gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf text_under.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-underline.png text_under.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf filenew.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-new.png filenew.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-address-book.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf address-book-new.png stock_new-address-book.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_print-preview.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print-preview.png stock_print-preview.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf filequickprint.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print-preview.png filequickprint.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-backward.png gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_search-and-replace.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find-replace.png stock_search-and-replace.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf window_fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-fullscreen.png window_fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf forward.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-next.png forward.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-paste.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-paste.png gtk-paste.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf leftjust.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-left.png leftjust.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-copy.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-copy.png gtk-copy.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf up.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-up.png up.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-previous.png gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-forward.png player_fwd.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf text_bold.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-bold.png text_bold.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-pause.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-pause.png stock_media-pause.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-save-as.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save-as.png gtk-save-as.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf window_new.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf window-new.png window_new.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gohome.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-home.png gohome.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-execute.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-run.png gtk-execute.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-first.png gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-restore.png stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gnome-logout.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf system-log-out.png gnome-logout.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_justify.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-fill.png stock_text_justify.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf top.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-top.png top.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-fullscreen.png stock_fullscreen.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-strikethrough.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-strikethrough.png gtk-strikethrough.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-window.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf window-new.png stock_new-window.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_play.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-start.png player_play.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-next.png gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf filefind.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find.png filefind.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf back.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-previous.png back.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf undo.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-undo.png undo.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_new-text.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-new.png stock_new-text.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf reload.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-refresh.png reload.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf mail_spam.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-mark-junk.png mail_spam.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_start.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-backward.png player_start.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf player_eject.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-eject.png player_eject.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-backward.png gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf fileprint.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print.png fileprint.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_left.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-previous.png stock_left.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-first.png gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_cut.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-cut.png stock_cut.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf find.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-find.png find.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf finish.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-last.png finish.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-play.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-start.png stock_media-play.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_unindent.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-indent-less.png stock_text_unindent.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-open.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-open.png gtk-open.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_file-properites.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-properties.png stock_file-properites.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf start.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf go-first.png start.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-sort-ascending.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf view-sort-ascending.png gtk-sort-ascending.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-save.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-save.png gtk-save.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf centrejust.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-justify-center.png centrejust.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_mail-send-receive.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf mail-send-receive.png stock_mail-send-receive.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_print.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-print.png stock_print.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-skip-backward.png gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-properties.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf document-properties.png gtk-properties.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-playback-stop.png stock_media-stop.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_copy.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf edit-copy.png stock_copy.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_media-rew.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf media-seek-backward.png stock_media-rew.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf stock_text_bold.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf format-text-bold.png stock_text_bold.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf gtk-add.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf list-add.png gtk-add.png )
( cd usr/share/icons/gnome/16x16/actions ; rm -rf appointment.png )
( cd usr/share/icons/gnome/16x16/actions ; ln -sf appointment-new.png appointment.png )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf emblem-noread.icon )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-unreadable.icon emblem-noread.icon )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf emblem-nowrite.svg )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-readonly.svg emblem-nowrite.svg )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf stock_mail-priority-high.icon )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-important.icon stock_mail-priority-high.icon )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf emblem-noread.svg )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-unreadable.svg emblem-noread.svg )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf stock_mail-priority-high.svg )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-important.svg stock_mail-priority-high.svg )
( cd usr/share/icons/gnome/scalable/emblems ; rm -rf emblem-nowrite.icon )
( cd usr/share/icons/gnome/scalable/emblems ; ln -sf emblem-readonly.icon emblem-nowrite.icon )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf image-x-generic.svg image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf package_wordprocessing.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg package_wordprocessing.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-x-kpresenter.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-calendar.svg gnome-mime-text-x-vcalendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-vnd.stardivision.impress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf audio-x-generic.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf rpm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg rpm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-vbr.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg gnome-mime-application-vnd.rn-realmedia-vbr.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-archive.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-archive.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text-web.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg gnome-mime-application-vnd.oasis.opendocument.text-web.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-wordperfect.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-wordperfect.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-fs-regular.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-preview.svg gnome-fs-regular.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf ascii.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg ascii.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-drawing.svg gnome-mime-application-vnd.oasis.opendocument.image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-vnd.stardivision.writer.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf binary.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-x-executable.svg binary.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf kpresenter_kpr.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg kpresenter_kpr.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf sound.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf audio-x-generic.svg sound.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf stock_script.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg stock_script.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf package_editors.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg package_editors.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf font_bitmap.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg font_bitmap.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gtk-file.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-preview.svg gtk-file.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-dvi.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-dvi.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-shellscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-application-x-shellscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf font_truetype.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg font_truetype.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-rtf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-rtf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-msword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-msword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-secure.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg gnome-mime-application-vnd.rn-realmedia-secure.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-vnd.ms-excel.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-compress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-compress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf deb.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg deb.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf www.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg www.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-audio.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf audio-x-generic.svg gnome-mime-audio.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-x-applix-spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf wordprocessing.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg wordprocessing.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-x-font-afm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-x-font-afm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-applix-word.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-applix-word.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-jar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-jar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf folder_tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg folder_tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-arj.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-arj.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-php.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg gnome-mime-application-x-php.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-cpio-compressed.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-ms-dos-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-x-executable.svg gnome-mime-application-x-ms-dos-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf txt2.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg txt2.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-application-x-python-bytecode.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf stock_addressbook.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-address-book.svg stock_addressbook.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-magicpoint.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-magicpoint.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gtk-file.icon )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-preview.icon gtk-file.icon )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-postscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-postscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-x-executable.svg gnome-mime-application-x-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf contents2.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-address-book.svg contents2.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf stock_certificate.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-certificate.svg stock_certificate.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-zip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-zip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf image-x-generic.svg gnome-mime-image.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf zip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg zip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-zsh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-text-x-zsh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-drawing.svg gnome-mime-application-vnd.sun.xml.draw.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf vcard.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-address-book.svg vcard.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-vnd.sun.xml.writer.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-vnd.stardivision.calc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-vnd.sun.xml.calc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-xhtml+xml.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg gnome-mime-application-xhtml+xml.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-vnd.oasis.opendocument.spreadsheet.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf misc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg misc.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf shellscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg shellscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-gzpostscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-gzpostscript.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-lhz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-lhz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.presentation.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-vnd.oasis.opendocument.presentation.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-lha.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-lha.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg gnome-mime-application-x-shockwave-flash.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-tex.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-tex.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf stock_calendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-calendar.svg stock_calendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-sunos-news.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-fs-regular.icon )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-preview.icon gnome-fs-regular.icon )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf empty.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg empty.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-rpm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-rpm.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf font.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg font.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-cpio.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-cpio.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-sh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-text-x-sh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-lzma.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-lzma.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-package.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-package.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf unknown.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg unknown.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-deb.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-deb.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-perl.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-application-x-perl.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-7z-compressed.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-7z-compressed.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-vnd.ms-powerpoint.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf vcalendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-calendar.svg vcalendar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf document.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg document.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-vnd.oasis.opendocument.text.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-video.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg gnome-mime-video.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg gnome-mime-text.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-vcard.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-address-book.svg gnome-mime-text-x-vcard.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-bzip-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf mime_ascii.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg mime_ascii.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-kword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-kword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf txt.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic.svg txt.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf template_source.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-generic-template.svg template_source.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf font_type1.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf font-x-generic.svg font_type1.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-abiword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-abiword.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-html.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg gnome-mime-text-html.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-tarz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-tarz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-csh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-text-x-csh.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-bzip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-bzip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg gnome-mime-application-vnd.rn-realmedia.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-rar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-rar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-gzip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-gzip.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf plan.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-calendar.svg plan.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-vnd.lotus-1-2-3.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf exec.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-x-executable.svg exec.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-fs-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf application-x-executable.svg gnome-fs-executable.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-presentation.svg gnome-mime-application-vnd.sun.xml.impress.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.graphics.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-drawing.svg gnome-mime-application-vnd.oasis.opendocument.graphics.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-pdf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-pdf.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf tgz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg tgz.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-kspread.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-spreadsheet.svg gnome-mime-application-x-kspread.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf package.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg package.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-x-python.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-x-script.svg gnome-mime-text-x-python.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-scribus.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf x-office-document.svg gnome-mime-application-x-scribus.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf video.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf video-x-generic.svg video.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-lzma-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf package-x-generic.svg gnome-mime-application-x-lzma-compressed-tar.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-application-x-killustrator.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf image-x-generic.svg gnome-mime-application-x-killustrator.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf html.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg html.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; rm -rf gnome-mime-text-vnd.wap.wml.svg )
( cd usr/share/icons/gnome/scalable/mimetypes ; ln -sf text-html.svg gnome-mime-text-vnd.wap.wml.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf stock_internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-internet.svg stock_internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-multimedia.svg package_multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-devel.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-development.svg gnome-devel.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-internet.svg redhat-internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-games.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-games.svg xfce-games.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_development.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-development.svg package_development.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-system.svg package_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce4-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg xfce4-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-system-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-system.svg xfce-system-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_network.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-internet.svg package_network.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-util.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-accessories.svg gnome-util.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-system_tools.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-system.svg redhat-system_tools.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-control-center.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg gnome-control-center.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-other.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-other.svg gnome-other.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-preferences.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg redhat-preferences.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-office.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-office.svg redhat-office.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_utilities.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-accessories.svg package_utilities.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-joystick.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-games.svg gnome-joystick.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-graphics.svg gnome-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-games.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-games.svg redhat-games.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-system_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-system.svg redhat-system_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gtk-preferences.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg gtk-preferences.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-applications.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-office.svg gnome-applications.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-globe.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-internet.svg gnome-globe.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-system.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-system.svg gnome-system.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_games.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-games.svg package_games.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-graphics.svg package_graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf kcontrol.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg kcontrol.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-sound_video.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-multimedia.svg redhat-sound_video.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-utils.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-accessories.svg xfce-utils.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_office.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-office.svg package_office.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-multimedia.svg gnome-multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-accessories.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-accessories.svg redhat-accessories.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-graphics.svg redhat-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-multimedia.svg xfce-multimedia.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf gnome-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop.svg gnome-settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf package_system.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-system.svg package_system.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-graphics.svg xfce-graphics.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-internet.svg xfce-internet.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf input_devices_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf preferences-desktop-peripherals.svg input_devices_settings.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf xfce-office.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-office.svg xfce-office.svg )
( cd usr/share/icons/gnome/scalable/categories ; rm -rf redhat-programming.svg )
( cd usr/share/icons/gnome/scalable/categories ; ln -sf applications-development.svg redhat-programming.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-harddisk-1394.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg gnome-dev-harddisk-1394.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf printer1.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg printer1.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-keyboard.svg gnome-dev-keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-dvdram.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-dvdram.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_HD.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg yast_HD.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf dvd_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg dvd_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-computer.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf computer.svg gnome-dev-computer.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gtk-harddisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg gtk-harddisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg gnome-dev-printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf xfce4-display.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf video-display.svg xfce4-display.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-ipod.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf multimedia-player.svg gnome-dev-ipod.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_idetude.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg yast_idetude.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-media-ms.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-flash.svg gnome-dev-media-ms.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-media-sm.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-flash.svg gnome-dev-media-sm.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-dvdrw.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-dvdrw.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf printer-remote.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg printer-remote.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_soundcard.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf audio-card.svg yast_soundcard.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-cdr.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-cdr.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-stock-mic.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf audio-input-microphone.svg gnome-stock-mic.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf harddrive.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg harddrive.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-cdrom-audio.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-cdrom-audio.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf stock_mic.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf audio-input-microphone.svg stock_mic.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-dvdr-plus.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-dvdr-plus.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-battery.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf battery.svg gnome-dev-battery.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf drive-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-optical.svg drive-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf system.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf computer.svg system.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf chardevice.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf video-display.svg chardevice.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf xfce4-keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-keyboard.svg xfce4-keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg yast_printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf printmgr.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg printmgr.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf joystick.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-gaming.svg joystick.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-removable.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-removable-media.svg gnome-dev-removable.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-optical.svg gnome-dev-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gtk-floppy.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-floppy.svg gtk-floppy.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-mouse-optical.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-mouse.svg gnome-dev-mouse-optical.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf camera_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf camera-photo.svg camera_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-zipdisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-zip.svg gnome-dev-zipdisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_joystick.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-gaming.svg yast_joystick.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf media-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg media-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-cdrw.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-cdrw.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf display.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf video-display.svg display.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf yast_mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-mouse.svg yast_mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-dvd.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-optical.svg gnome-dev-dvd.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-wavelan.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf network-wireless.svg gnome-dev-wavelan.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf xfce4-mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-mouse.svg xfce4-mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf 3floppy_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-floppy.svg 3floppy_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-media-sdmmc.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-flash.svg gnome-dev-media-sdmmc.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf system-floppy.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-floppy.svg system-floppy.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf cdwriter_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg cdwriter_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-keyboard.svg keyboard.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-ethernet.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf network-wired.svg gnome-dev-ethernet.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf kxkb.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-keyboard.svg kxkb.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf xfce-printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg xfce-printer.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gtk-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gtk-cdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-harddisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg gnome-dev-harddisk.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-dvdr.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-dvdr.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf cdrom_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg cdrom_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-modem.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf modem.svg gnome-modem.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf ipod_mount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf multimedia-player.svg ipod_mount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-mouse-ball.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-mouse.svg gnome-dev-mouse-ball.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-media-cf.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-flash.svg gnome-dev-media-cf.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf input-mouse.svg mouse.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-fs-client.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf computer.svg gnome-fs-client.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf camera.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf camera-photo.svg camera.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-harddisk-usb.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg gnome-dev-harddisk-usb.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-removable-usb.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-removable-media.svg gnome-dev-removable-usb.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf usbpendrive_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-removable-media.svg usbpendrive_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf hdd_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-harddisk.svg hdd_unmount.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-disc-dvdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-optical.svg gnome-dev-disc-dvdrom.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf kjobviewer.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg kjobviewer.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-removable-1394.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf drive-removable-media.svg gnome-dev-removable-1394.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf stock_cell-phone.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf phone.svg stock_cell-phone.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf stock_printers.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf printer.svg stock_printers.svg )
( cd usr/share/icons/gnome/scalable/devices ; rm -rf gnome-dev-floppy.svg )
( cd usr/share/icons/gnome/scalable/devices ; ln -sf media-floppy.svg gnome-dev-floppy.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-night-clear.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-clear-night.svg stock_weather-night-clear.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf sunny.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-clear.svg sunny.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf nm-device-wired.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-idle.svg nm-device-wired.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf trashcan_full.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg trashcan_full.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_lock-ok.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf security-high.svg stock_lock-ok.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_dialog-error.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-error.svg stock_dialog-error.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-idle.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-idle.svg gnome-netstatus-idle.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-dialog-authentication.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-password.svg gtk-dialog-authentication.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_trash_full.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg stock_trash_full.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf error.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-error.svg error.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume-0.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-low.svg stock_volume-0.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_dialog-warning.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-warning.svg stock_dialog-warning.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-directory-visiting.icon )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-visiting.icon gnome-fs-directory-visiting.icon )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-directory-visiting.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-visiting.svg gnome-fs-directory-visiting.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-trash-full.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg gnome-fs-trash-full.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-cloudy.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-overcast.svg stock_weather-cloudy.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume-min.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-low.svg stock_volume-min.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_lock-broken.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf security-low.svg stock_lock-broken.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-tx.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-transmit.svg gnome-netstatus-tx.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_appointment-reminder-excl.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf appointment-missed.svg stock_appointment-reminder-excl.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_mail-unread.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf mail-unread.svg stock_mail-unread.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf folder_open.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-open.svg folder_open.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_dialog-question.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-question.svg stock_dialog-question.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-txrx.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-transmit-receive.svg gnome-netstatus-txrx.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-fog.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-fog.svg stock_weather-fog.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf folder_open.icon )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-open.icon folder_open.icon )
( cd usr/share/icons/gnome/scalable/status ; rm -rf messagebox_critical.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-error.svg messagebox_critical.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_lock.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf security-medium.svg stock_lock.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_shuffle.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf media-playlist-shuffle.svg stock_shuffle.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume-max.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-high.svg stock_volume-max.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-sunny.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-clear.svg stock_weather-sunny.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf nm-adhoc.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-idle.svg nm-adhoc.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf connect_established.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-idle.svg connect_established.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-showers.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-showers.svg stock_weather-showers.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf connect_creating.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-transmit-receive.svg connect_creating.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-storm.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-storm.svg stock_weather-storm.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-rx.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-receive.svg gnome-netstatus-rx.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-error.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-error.svg gnome-netstatus-error.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_attach.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf mail-attachment.svg stock_attach.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-dialog-question.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-question.svg gtk-dialog-question.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_lock-open.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf security-low.svg stock_lock-open.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-night-few-clouds.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-few-clouds-night.svg stock_weather-night-few-clouds.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-snow.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-snow.svg stock_weather-snow.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-dialog-warning.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-warning.svg gtk-dialog-warning.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_mail-open.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf mail-read.svg stock_mail-open.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-dialog-info.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-information.svg gtk-dialog-info.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-netstatus-disconn.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-offline.svg gnome-netstatus-disconn.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-loading-icon.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf image-loading.svg gnome-fs-loading-icon.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_weather-few-clouds.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf weather-few-clouds.svg stock_weather-few-clouds.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_mail-replied.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf mail-replied.svg stock_mail-replied.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf nm-device-wireless.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-idle.svg nm-device-wireless.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf nm-no-connection.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-offline.svg nm-no-connection.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume-mute.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-muted.svg stock_volume-mute.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf messagebox_info.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-information.svg messagebox_info.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf important.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-warning.svg important.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf info.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-information.svg info.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-directory-accept.icon )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-drag-accept.icon gnome-fs-directory-accept.icon )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-high.svg stock_volume.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_open.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-open.svg stock_open.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_appointment-reminder.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf appointment-soon.svg stock_appointment-reminder.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_repeat.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf media-playlist-repeat.svg stock_repeat.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-stock-trash-full.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg gnome-stock-trash-full.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_volume-med.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf audio-volume-medium.svg stock_volume-med.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-missing-image.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf image-missing.svg gtk-missing-image.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf connect_no.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf network-offline.svg connect_no.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf xfce-trash_full.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg xfce-trash_full.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gtk-dialog-error.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-error.svg gtk-dialog-error.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_dialog-info.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-information.svg stock_dialog-info.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf gnome-fs-directory-accept.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-drag-accept.svg gnome-fs-directory-accept.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf stock_open.icon )
( cd usr/share/icons/gnome/scalable/status ; ln -sf folder-open.icon stock_open.icon )
( cd usr/share/icons/gnome/scalable/status ; rm -rf edittrash.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf user-trash-full.svg edittrash.svg )
( cd usr/share/icons/gnome/scalable/status ; rm -rf messagebox_warning.svg )
( cd usr/share/icons/gnome/scalable/status ; ln -sf dialog-warning.svg messagebox_warning.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-settings-accessibility-technologies.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-accessibility.svg gnome-settings-accessibility-technologies.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-window-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-system-windows.svg gnome-window-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf screensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-screensaver.svg screensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xfwm4.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-system-windows.svg xfwm4.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf calc.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-calculator.svg calc.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kcmsound.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg kcmsound.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xfce-filemanager.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-file-manager.svg xfce-filemanager.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf krfb.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-remote-desktop.svg krfb.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gucharmap.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-character-map.svg gucharmap.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xscreensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-screensaver.svg xscreensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kedit.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-text-editor.svg kedit.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf background.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-wallpaper.svg background.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-terminal.svg gnome-terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-monitor.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-system-monitor.svg gnome-monitor.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-settings-theme.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-theme.svg gnome-settings-theme.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xfce4-backdrop.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-wallpaper.svg xfce4-backdrop.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-settings-keybindings.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-keyboard-shortcuts.svg gnome-settings-keybindings.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf fonts.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-font.svg fonts.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xfce-terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-terminal.svg xfce-terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf update-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-software-update.svg update-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf ksysguard.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-system-monitor.svg ksysguard.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf access.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-accessibility.svg access.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf locale.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-locale.svg locale.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kcharselect.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-character-map.svg kcharselect.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-remote-desktop.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-remote-desktop.svg gnome-remote-desktop.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf xfce4-mixer.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg xfce4-mixer.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf style.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-theme.svg style.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-terminal.svg terminal.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kscreensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-screensaver.svg kscreensaver.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf zen-icon.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-software-update.svg zen-icon.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf system-config-users.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-users.svg system-config-users.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf redhat-filemanager.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-file-manager.svg redhat-filemanager.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kcalc.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-calculator.svg kcalc.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf config-users.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-users.svg config-users.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf arts.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg arts.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf volume-knob.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg volume-knob.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kwin.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-system-windows.svg kwin.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf key_bindings.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-keyboard-shortcuts.svg key_bindings.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf khelpcenter.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg khelpcenter.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-character-map.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-character-map.svg gnome-character-map.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf accessibility-directory.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-accessibility.svg accessibility-directory.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-settings-font.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-font.svg gnome-settings-font.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kcmkwm.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-system-windows.svg kcmkwm.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf konsole.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-terminal.svg konsole.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf text-editor.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-text-editor.svg text-editor.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kfm.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-file-manager.svg kfm.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf file-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-file-manager.svg file-manager.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-settings-background.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-wallpaper.svg gnome-settings-background.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf stock_help.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg stock_help.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-mixer.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg gnome-mixer.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-help.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg gnome-help.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf multimedia.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf multimedia-volume-control.svg multimedia.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf help.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg help.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf kuser.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf system-users.svg kuser.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gtk-help.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg gtk-help.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf config-language.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-locale.svg config-language.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf susehelpcenter.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf help-browser.svg susehelpcenter.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf wallpaper.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf preferences-desktop-wallpaper.svg wallpaper.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf gnome-calculator.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf accessories-calculator.svg gnome-calculator.svg )
( cd usr/share/icons/gnome/scalable/apps ; rm -rf openterm.svg )
( cd usr/share/icons/gnome/scalable/apps ; ln -sf utilities-terminal.svg openterm.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-1.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-smile.svg stock_smiley-1.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-7.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-smile.svg stock_smiley-7.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-10.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-raspberry.svg stock_smiley-10.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-8.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-plain.svg stock_smiley-8.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-2.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-smile.svg stock_smiley-2.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-18.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-angel.svg stock_smiley-18.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-11.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-crying.svg stock_smiley-11.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-13.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-kiss.svg stock_smiley-13.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-15.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-cool.svg stock_smiley-15.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-22.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-monkey.svg stock_smiley-22.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-6.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-smile-big.svg stock_smiley-6.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-5.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-surprise.svg stock_smiley-5.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-4.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-sad.svg stock_smiley-4.svg )
( cd usr/share/icons/gnome/scalable/emotes ; rm -rf stock_smiley-3.svg )
( cd usr/share/icons/gnome/scalable/emotes ; ln -sf face-wink.svg stock_smiley-3.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf inode-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.svg inode-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf network_local.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-workgroup.svg network_local.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-ssh.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-fs-ssh.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-share.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-fs-share.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf server.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-server.svg server.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf network.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg network.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-stock-trash.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-trash.svg gnome-stock-trash.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-smb.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-fs-smb.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-home.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-home.svg gnome-fs-home.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gtk-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.icon gtk-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf stock_folder.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.svg stock_folder.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf trashcan_empty.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-trash.svg trashcan_empty.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-nfs.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-fs-nfs.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf novell-button.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf start-here.svg novell-button.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-server.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-server.svg gnome-fs-server.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf network.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon network.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-mime-x-directory-nfs-server.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-server.svg gnome-mime-x-directory-nfs-server.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.svg gnome-fs-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf xfce-trash_empty.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-trash.svg xfce-trash_empty.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf stock_folder.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.icon stock_folder.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-smb.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-fs-smb.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-ftp.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-fs-ftp.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-trash-empty.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-trash.svg gnome-fs-trash-empty.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-ssh.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-fs-ssh.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf redhat-network-server.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-server.svg redhat-network-server.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gtk-network.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-workgroup.svg gtk-network.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf application-x-gnome-saved-search.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-saved-search.svg application-x-gnome-saved-search.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-ftp.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-fs-ftp.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf inode-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.icon inode-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gtk-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.svg gtk-directory.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-nfs.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-fs-nfs.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf desktop.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-desktop.svg desktop.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf emptytrash.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-trash.svg emptytrash.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf distributor-logo.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf start-here.svg distributor-logo.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-mime-x-directory-smb-share.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-mime-x-directory-smb-share.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-desktop.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-desktop.svg gnome-fs-desktop.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-mime-x-directory-smb-workgroup.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-workgroup.svg gnome-mime-x-directory-smb-workgroup.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf folder_home.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf user-home.svg folder_home.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-share.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.svg gnome-fs-share.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder.icon gnome-fs-directory.icon )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-main-menu.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf start-here.svg gnome-main-menu.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-mime-x-directory-smb-server.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-server.svg gnome-mime-x-directory-smb-server.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-fs-network.svg )
( cd usr/share/icons/gnome/scalable/places ; ln -sf network-workgroup.svg gnome-fs-network.svg )
( cd usr/share/icons/gnome/scalable/places ; rm -rf gnome-mime-x-directory-smb-share.icon )
( cd usr/share/icons/gnome/scalable/places ; ln -sf folder-remote.icon gnome-mime-x-directory-smb-share.icon )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-stop.svg gtk-media-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-send.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-send.svg stock_mail-send.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf reload.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg reload.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf editcopy.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-copy.svg editcopy.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-up.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-up.svg gtk-go-up.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_delete.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-delete.svg stock_delete.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-save.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save.svg gtk-save.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_close.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf window-close.svg stock_close.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_leave-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-restore.svg stock_leave-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_zoom-page.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-fit-best.svg stock_zoom-page.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-lockscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-lock-screen.svg gnome-lockscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_copy.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-copy.svg stock_copy.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf text_bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-bold.svg text_bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf fileprint.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print.svg fileprint.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_file-properites.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-properties.svg stock_file-properites.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text-strikethrough.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-strikethrough.svg stock_text-strikethrough.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-first-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-last.svg gtk-goto-first-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-next-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-backward.svg gtk-media-next-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf reload_all_tabs.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg reload_all_tabs.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_left.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-previous.svg stock_left.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-zoom-fit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-fit-best.svg gtk-zoom-fit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-find.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find.svg gtk-find.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-revert-to-saved-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-revert.svg gtk-revert-to-saved-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-back-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-previous.svg gtk-go-back-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf xfce-system-lock.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-lock-screen.svg xfce-system-lock.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-bottom.svg gtk-goto-bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_undo.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-undo.svg stock_undo.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf text_strike.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-strikethrough.svg text_strike.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-window.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf window-new.svg stock_new-window.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf filefind.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find.svg filefind.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_center.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-center.svg stock_text_center.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-mail-new.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-message-new.svg gnome-stock-mail-new.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-appointment.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf appointment-new.svg stock_new-appointment.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_add-bookmark.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf bookmark-new.svg stock_add-bookmark.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-fullscreen.svg gtk-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-forward-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-forward.svg gtk-media-forward-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-add.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf list-add.svg gtk-add.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-indent-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-more.svg gtk-indent-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf mail_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-message-new.svg mail_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-pause.svg gtk-media-pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-back-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-next.svg gtk-go-back-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-address-book.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf address-book-new.svg stock_new-address-book.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-send-receive.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-send-receive.svg stock_mail-send-receive.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_eject.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-eject.svg player_eject.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-zoom-in.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-in.svg gtk-zoom-in.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_about.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf help-about.svg stock_about.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-redo-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-redo.svg gtk-redo-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-previous-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-forward.svg gtk-media-previous-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf kfind.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-search.svg kfind.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf window_nofullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-restore.svg window_nofullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-play.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-start.svg stock_media-play.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf bookmarks_list_add.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf bookmark-new.svg bookmarks_list_add.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_indent.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-more.svg stock_text_indent.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-jump-to-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-jump.svg gtk-jump-to-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf viewmagfit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-fit-best.svg viewmagfit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-jump-to-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-jump.svg gtk-jump-to-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf reload_page.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg reload_page.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-properties.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-properties.svg gtk-properties.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-next.svg forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-about.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf help-about.svg gtk-about.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-print.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print.svg gtk-print.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_print-setup.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-page-setup.svg stock_print-setup.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-stop.svg stock_media-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_cut.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-cut.svg stock_cut.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_properties.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-properties.svg stock_properties.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-refresh.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg gtk-refresh.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_save.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save.svg stock_save.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf previous.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-previous.svg previous.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-revert-to-saved-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-revert.svg gtk-revert-to-saved-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_print-preview.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print-preview.svg stock_print-preview.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-select-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-select-all.svg gtk-select-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf editcut.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-cut.svg editcut.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-rewind-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-forward.svg gtk-media-rewind-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_help-add-bookmark.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf bookmark-new.svg stock_help-add-bookmark.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-compose.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-message-new.svg stock_mail-compose.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf back.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-previous.svg back.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-paste.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-paste.svg gtk-paste.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_select-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-select-all.svg stock_select-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-cancel.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf process-stop.svg gtk-cancel.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-forward-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-previous.svg gtk-go-forward-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf viewmag+.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-in.svg viewmag+.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf text_under.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-underline.svg text_under.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-down.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-down.svg gtk-go-down.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf bookmark_add.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf bookmark-new.svg bookmark_add.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-bold.svg stock_text_bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf mail_forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-forward.svg mail_forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-rewind-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-backward.svg gtk-media-rewind-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-mail-fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-forward.svg gnome-stock-mail-fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-pause.svg stock_media-pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf redo.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-redo.svg redo.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-leave-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-restore.svg gtk-leave-fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-searchtool.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-search.svg gnome-searchtool.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_start.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-backward.svg player_start.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_last.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-last.svg stock_last.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf filesaveas.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save-as.svg filesaveas.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_zoom-1.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-original.svg stock_zoom-1.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_up.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-up.svg stock_up.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_zoom-in.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-in.svg stock_zoom-in.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf up.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-up.svg up.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-justify-fill.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-fill.svg gtk-justify-fill.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-fullscreen.svg stock_fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_redo.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-redo.svg stock_redo.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-go-forward-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-next.svg gtk-go-forward-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-bottom.svg stock_bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_zoom-out.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-out.svg stock_zoom-out.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf kfm_home.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-home.svg kfm_home.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_right.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-right.svg stock_text_right.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-reply.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-reply-sender.svg stock_mail-reply.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_refresh.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg stock_refresh.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-bottom.svg bottom.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gohome.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-home.svg gohome.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-forward.svg player_fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-forward.svg stock_mail-forward.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf editdelete.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-delete.svg editdelete.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf editclear.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-clear.svg editclear.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-text-unindent.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-less.svg gnome-stock-text-unindent.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-mail-rpl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-reply-sender.svg gnome-stock-mail-rpl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-find-and-replace.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find-replace.svg gtk-find-and-replace.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-quit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf application-exit.svg gtk-quit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-run.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-run.svg gnome-run.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf filesave.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save.svg filesave.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-home.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-home.svg gtk-home.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-text-indent.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-more.svg gnome-stock-text-indent.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_unindent.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-less.svg stock_text_unindent.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-strikethrough.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-strikethrough.svg gtk-strikethrough.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-rew.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-backward.svg stock_media-rew.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-forward.svg stock_media-fwd.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf fileopen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-open.svg fileopen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf process-stop.svg stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-play-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-start.svg gtk-media-play-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf redhat-home.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-home.svg redhat-home.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_right.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-next.svg stock_right.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-next-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-forward.svg gtk-media-next-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf filenew.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-new.svg filenew.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_top.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-top.svg stock_top.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-stock-mail-snd.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-send.svg gnome-stock-mail-snd.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-justify-left.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-left.svg gtk-justify-left.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf top.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-top.svg top.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf next.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-next.svg next.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-logout.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-log-out.svg gnome-logout.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_print.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print.svg stock_print.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-pause.svg player_pause.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-remove.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf list-remove.svg gtk-remove.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-sort-ascending.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-sort-ascending.svg gtk-sort-ascending.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf exit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf application-exit.svg exit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_home.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-home.svg stock_home.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_rew.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-backward.svg player_rew.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf leftjust.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-left.svg leftjust.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf text_italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-italic.svg text_italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf filequickprint.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print-preview.svg filequickprint.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-open.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-open.svg gtk-open.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf add.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf list-add.svg add.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf remove.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf list-remove.svg remove.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-text.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-new.svg stock_new-text.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf rightjust.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-right.svg rightjust.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-cut.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-cut.svg gtk-cut.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_paste.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-paste.svg stock_paste.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-sort-descending.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-sort-descending.svg gtk-sort-descending.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf window_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf window-new.svg window_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-prev.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-backward.svg stock_media-prev.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-execute.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-run.svg gtk-execute.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-indent-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-less.svg gtk-indent-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf centrejust.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-center.svg centrejust.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-zoom-100.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-original.svg gtk-zoom-100.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf start.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-first.svg start.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf window_fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-fullscreen.svg window_fullscreen.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf down.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-down.svg down.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-last-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-first.svg gtk-goto-last-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf reload3.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf view-refresh.svg reload3.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_record.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-record.svg player_record.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_search-and-replace.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find-replace.svg stock_search-and-replace.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf editpaste.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-paste.svg editpaste.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_mail-reply-to-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-reply-all.svg stock_mail-reply-to-all.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_down.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-down.svg stock_down.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-unindent-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-less.svg gtk-unindent-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf process-stop.svg gtk-stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-top.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-top.svg gtk-goto-top.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-last-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-last.svg gtk-goto-last-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-save-as.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save-as.svg gtk-save-as.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-zoom-out.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-out.svg gtk-zoom-out.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-next.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-forward.svg stock_media-next.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-spell-check.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf tools-check-spelling.svg gtk-spell-check.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-close.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf window-close.svg gtk-close.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_left.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-left.svg stock_text_left.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-print-preview.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-print-preview.svg gtk-print-preview.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-stop.svg player_stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf find.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find.svg find.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf appointment.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf appointment-new.svg appointment.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf mail_reply.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-reply-sender.svg mail_reply.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-undo-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-undo.svg gtk-undo-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-unindent-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-indent-more.svg gtk-unindent-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_spellcheck.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf tools-check-spelling.svg stock_spellcheck.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_first.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-first.svg stock_first.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf search.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-search.svg search.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-bold.svg gtk-bold.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf viewmag1.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-original.svg viewmag1.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_justify.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-fill.svg stock_text_justify.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-underline.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-underline.svg gtk-underline.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf revert.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-revert.svg revert.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf folder_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf folder-new.svg folder_new.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-italic.svg stock_text_italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf undo.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-undo.svg undo.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf process-stop.svg stock_stop.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf finish.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-last.svg finish.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_text_underlined.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-underline.svg stock_text_underlined.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf xfce-system-exit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf application-exit.svg xfce-system-exit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_media-rec.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-record.svg stock_media-rec.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-dir.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf folder-new.svg stock_new-dir.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-copy.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-copy.svg gtk-copy.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-forward-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-seek-backward.svg gtk-media-forward-rtl.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf zoom-best-fit.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-fit-best.svg zoom-best-fit.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-previous-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-backward.svg gtk-media-previous-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-delete.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-delete.svg gtk-delete.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-new.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-new.svg gtk-new.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf viewmag-.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf zoom-out.svg viewmag-.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf mail_replyall.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-reply-all.svg mail_replyall.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-text-italic.svg gtk-italic.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf mail_send.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf mail-send.svg mail_send.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_new-bcard.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf contact-new.svg stock_new-bcard.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_end.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-skip-forward.svg player_end.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gnome-shutdown.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-shutdown.svg gnome-shutdown.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-clear.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-clear.svg gtk-clear.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_search.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf edit-find.svg stock_search.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf stock_save-as.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf document-save-as.svg stock_save-as.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-justify-right.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-right.svg gtk-justify-right.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-justify-center.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf format-justify-center.svg gtk-justify-center.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-goto-first-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf go-first.svg gtk-goto-first-ltr.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf player_play.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-playback-start.svg player_play.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf gtk-media-record.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf media-record.svg gtk-media-record.svg )
( cd usr/share/icons/gnome/scalable/actions ; rm -rf lock.svg )
( cd usr/share/icons/gnome/scalable/actions ; ln -sf system-lock-screen.svg lock.svg )
( cd usr/share/icons/gnome/32x32/emblems ; rm -rf emblem-noread.png )
( cd usr/share/icons/gnome/32x32/emblems ; ln -sf emblem-unreadable.png emblem-noread.png )
( cd usr/share/icons/gnome/32x32/emblems ; rm -rf stock_mail-priority-high.png )
( cd usr/share/icons/gnome/32x32/emblems ; ln -sf emblem-important.png stock_mail-priority-high.png )
( cd usr/share/icons/gnome/32x32/emblems ; rm -rf emblem-nowrite.png )
( cd usr/share/icons/gnome/32x32/emblems ; ln -sf emblem-readonly.png emblem-nowrite.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png gnome-mime-text.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.oasis.opendocument.text.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf html.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png html.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-x-font-afm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf image-x-generic.png image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf www.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png www.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-sh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf stock_script.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png stock_script.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-address-book.png gnome-mime-text-x-vcard.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-msword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.stardivision.writer.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf document.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png document.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf rpm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png rpm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf vcard.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-address-book.png vcard.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.graphics.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf image-x-generic.png gnome-mime-application-x-killustrator.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png gnome-mime-application-x-php.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-abiword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-fs-regular.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-preview.png gnome-fs-regular.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-html.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png gnome-mime-text-html.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-pcf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf zip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png zip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf exec.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-x-executable.png exec.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf shellscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png shellscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.oasis.opendocument.presentation.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-jar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-archive.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-7z-compressed.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-zip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-magicpoint.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf txt2.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png txt2.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf folder_tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png folder_tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-scribus.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-sunos-news.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-fs-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-x-executable.png gnome-fs-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio-compressed.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-audio.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf audio-x-generic.png gnome-mime-audio.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-tex.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.sun.xml.draw.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-x-shockwave-flash.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.lotus-1-2-3.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.stardivision.calc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-linux-psf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf package.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png package.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf empty.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png empty.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-python-bytecode.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf unknown.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png unknown.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.ms-powerpoint.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-dvi.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-bdf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-applix-spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png gnome-mime-text-vnd.wap.wml.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-deb.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-gzpostscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf sound.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf audio-x-generic.png sound.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-package.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-package.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-ms-dos-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf stock_certificate.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-certificate.png stock_certificate.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-afm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-secure.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-pdf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-wordperfect.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.oasis.opendocument.spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-kword.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png gnome-mime-application-vnd.rn-realmedia-vbr.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-csh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lha.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf font_bitmap.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png font_bitmap.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-gzip.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf audio-x-generic.png gnome-mime-application-ogg.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png spreadsheet.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf contents2.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-address-book.png contents2.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-stuffit.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-zsh.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf mime_ascii.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png mime_ascii.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf package_editors.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png package_editors.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lhz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-gnumeric.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf misc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png misc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf template_source.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic-template.png template_source.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf wordprocessing.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png wordprocessing.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rpm.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-bzip-compressed-tar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf image-x-generic.png gnome-mime-image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf kpresenter_kpr.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png kpresenter_kpr.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-arj.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf stock_addressbook.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-address-book.png stock_addressbook.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf stock_calendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-calendar.png stock_calendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf font.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png font.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf binary.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-x-executable.png binary.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-tarz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf vcalendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-calendar.png vcalendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png gnome-mime-application-vnd.oasis.opendocument.text-web.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.sun.xml.calc.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-html.png gnome-mime-application-xhtml+xml.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-calendar.png gnome-mime-text-x-vcalendar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf ascii.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png ascii.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-vnd.ms-excel.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-drawing.png gnome-mime-application-vnd.oasis.opendocument.image.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.sun.xml.impress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf plan.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-calendar.png plan.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-cpio.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf tgz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png tgz.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-spreadsheet.png gnome-mime-application-x-kspread.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf package_wordprocessing.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png package_wordprocessing.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-text-x-python.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png gnome-mime-application-x-font-ttf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf txt.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-generic.png txt.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf video.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png video.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf font_truetype.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png font_truetype.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-vnd.stardivision.impress.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-rtf.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf application-x-executable.png gnome-mime-application-x-executable.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-rar.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf font_type1.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf font-x-generic.png font_type1.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png gnome-mime-application-x-lzma.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-vnd.sun.xml.writer.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-presentation.png gnome-mime-application-x-kpresenter.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-shellscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-script.png gnome-mime-application-x-perl.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-x-applix-word.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gtk-file.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf text-x-preview.png gtk-file.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf x-office-document.png gnome-mime-application-postscript.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf gnome-mime-video.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf video-x-generic.png gnome-mime-video.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; rm -rf deb.png )
( cd usr/share/icons/gnome/32x32/mimetypes ; ln -sf package-x-generic.png deb.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-multimedia.png gnome-multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-globe.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-internet.png gnome-globe.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-applications.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-office.png gnome-applications.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce4-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png xfce4-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-sound_video.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-multimedia.png redhat-sound_video.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-system.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-system.png gnome-system.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-control-center.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png gnome-control-center.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-multimedia.png xfce-multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-system_tools.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-system.png redhat-system_tools.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-preferences.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png redhat-preferences.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-graphics.png xfce-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png gnome-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-joystick.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-games.png gnome-joystick.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-office.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-office.png xfce-office.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-internet.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-internet.png redhat-internet.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-system-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-system.png xfce-system-settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_system.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-system.png package_system.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-internet.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-internet.png xfce-internet.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-office.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-office.png redhat-office.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-system.png package_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-programming.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-development.png redhat-programming.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_network.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-internet.png package_network.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_games.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-games.png package_games.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-graphics.png gnome-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_development.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-development.png package_development.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-games.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-games.png xfce-games.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_utilities.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-accessories.png package_utilities.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-graphics.png redhat-graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-util.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-accessories.png gnome-util.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf kcontrol.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png kcontrol.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-accessories.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-accessories.png redhat-accessories.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-multimedia.png package_multimedia.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf stock_internet.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-internet.png stock_internet.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-games.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-games.png redhat-games.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf redhat-system_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-system.png redhat-system_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-other.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-other.png gnome-other.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf input_devices_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop-peripherals.png input_devices_settings.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gtk-preferences.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf preferences-desktop.png gtk-preferences.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_office.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-office.png package_office.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf gnome-devel.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-development.png gnome-devel.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf package_graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-graphics.png package_graphics.png )
( cd usr/share/icons/gnome/32x32/categories ; rm -rf xfce-utils.png )
( cd usr/share/icons/gnome/32x32/categories ; ln -sf applications-accessories.png xfce-utils.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf printer1.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png printer1.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf cdwriter_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png cdwriter_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf stock_printers.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png stock_printers.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-floppy.png gnome-dev-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-flash.png gnome-dev-media-sm.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-flash.png gnome-dev-media-sdmmc.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-computer.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf computer.png gnome-dev-computer.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-dvd.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-optical.png gnome-dev-dvd.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gtk-harddisk.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png gtk-harddisk.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf stock_mic.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf audio-input-microphone.png stock_mic.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf xfce4-keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-keyboard.png xfce4-keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-mouse.png yast_mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf network-wired.png gnome-dev-ethernet.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_idetude.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png yast_idetude.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf harddrive.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png harddrive.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_soundcard.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf audio-card.png yast_soundcard.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf ipod_mount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf multimedia-player.png ipod_mount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-fs-client.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf computer.png gnome-fs-client.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-usb.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf kxkb.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-keyboard.png kxkb.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-keyboard.png keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf drive-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-optical.png drive-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-zip.png gnome-dev-zipdisk.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf usbpendrive_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-removable-media.png usbpendrive_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf cdrom_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png cdrom_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf display.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf video-display.png display.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-removable-media.png gnome-dev-removable-1394.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-battery.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf battery.png gnome-dev-battery.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-mouse.png mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf joystick.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-gaming.png joystick.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-cdrom-audio.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf 3floppy_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-floppy.png 3floppy_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-removable.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-removable-media.png gnome-dev-removable.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gtk-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gtk-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf dvd_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png dvd_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-mouse.png gnome-dev-mouse-optical.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf media-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png media-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-optical.png gnome-dev-cdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-keyboard.png gnome-dev-keyboard.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_joystick.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-gaming.png yast_joystick.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-ipod.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf multimedia-player.png gnome-dev-ipod.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-dvdram.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf xfce4-display.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf video-display.png xfce4-display.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf network-wireless.png gnome-dev-wavelan.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf xfce-printer.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png xfce-printer.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf system-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-floppy.png system-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf printer-remote.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png printer-remote.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-flash.png gnome-dev-media-cf.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-stock-mic.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf audio-input-microphone.png gnome-stock-mic.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf camera_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf camera-photo.png camera_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-modem.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf modem.png gnome-modem.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf camera.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf camera-photo.png camera.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-printer.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png gnome-dev-printer.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-cdr.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-flash.png gnome-dev-media-ms.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrw.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf stock_cell-phone.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf phone.png stock_cell-phone.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-dvdrom.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf xfce4-mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-mouse.png xfce4-mouse.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf system.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf computer.png system.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gtk-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-floppy.png gtk-floppy.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_printer.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png yast_printer.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf input-mouse.png gnome-dev-mouse-ball.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-cdrw.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf hdd_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png hdd_unmount.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf printmgr.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png printmgr.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf media-optical.png gnome-dev-disc-dvdr-plus.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf yast_HD.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png yast_HD.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-removable-media.png gnome-dev-removable-usb.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf kjobviewer.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf printer.png kjobviewer.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf chardevice.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf video-display.png chardevice.png )
( cd usr/share/icons/gnome/32x32/devices ; rm -rf gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/32x32/devices ; ln -sf drive-harddisk.png gnome-dev-harddisk-1394.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-transmit-receive.png gnome-netstatus-txrx.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf folder-visiting.png gnome-fs-directory-visiting.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_repeat.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf media-playlist-repeat.png stock_repeat.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_dialog-warning.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-warning.png stock_dialog-warning.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_lock-ok.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf security-high.png stock_lock-ok.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_mail-unread.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf mail-unread.png stock_mail-unread.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-password.png gtk-dialog-authentication.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_lock-open.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf security-low.png stock_lock-open.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-missing-image.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf image-missing.png gtk-missing-image.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf appointment-missed.png stock_appointment-reminder-excl.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf folder_open.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf folder-open.png folder_open.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf connect_no.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-offline.png connect_no.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf messagebox_info.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-information.png messagebox_info.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf edittrash.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png edittrash.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-cloudy.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-overcast.png stock_weather-cloudy.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-night-clear.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-clear-night.png stock_weather-night-clear.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-few-clouds.png stock_weather-few-clouds.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-dialog-warning.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-warning.png gtk-dialog-warning.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-dialog-question.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-question.png gtk-dialog-question.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume-med.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-medium.png stock_volume-med.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-error.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-error.png gnome-netstatus-error.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_attach.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf mail-attachment.png stock_attach.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf xfce-trash_full.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png xfce-trash_full.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf nm-device-wired.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-idle.png nm-device-wired.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-transmit.png gnome-netstatus-tx.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_appointment-reminder.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf appointment-soon.png stock_appointment-reminder.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_lock.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf security-medium.png stock_lock.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf folder-drag-accept.png gnome-fs-directory-accept.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf info.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-information.png info.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-receive.png gnome-netstatus-rx.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf trashcan_full.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png trashcan_full.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf nm-no-connection.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-offline.png nm-no-connection.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf connect_creating.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-transmit-receive.png connect_creating.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-idle.png gnome-netstatus-idle.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-high.png stock_volume.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-dialog-error.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-error.png gtk-dialog-error.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf error.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-error.png error.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_mail-open.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf mail-read.png stock_mail-open.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf image-loading.png gnome-fs-loading-icon.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_trash_full.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png stock_trash_full.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-showers.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-showers.png stock_weather-showers.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-few-clouds-night.png stock_weather-night-few-clouds.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_dialog-error.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-error.png stock_dialog-error.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-fog.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-fog.png stock_weather-fog.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-storm.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-storm.png stock_weather-storm.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume-0.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-low.png stock_volume-0.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-offline.png gnome-netstatus-disconn.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf connect_established.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-idle.png connect_established.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf nm-adhoc.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-idle.png nm-adhoc.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-sunny.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-clear.png stock_weather-sunny.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png gnome-stock-trash-full.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gtk-dialog-info.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-information.png gtk-dialog-info.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_lock-broken.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf security-low.png stock_lock-broken.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_dialog-info.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-information.png stock_dialog-info.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf important.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-warning.png important.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf user-trash-full.png gnome-fs-trash-full.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume-min.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-low.png stock_volume-min.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_mail-replied.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf mail-replied.png stock_mail-replied.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_open.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf folder-open.png stock_open.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf messagebox_critical.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-error.png messagebox_critical.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_weather-snow.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-snow.png stock_weather-snow.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_shuffle.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf media-playlist-shuffle.png stock_shuffle.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf messagebox_warning.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-warning.png messagebox_warning.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume-max.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-high.png stock_volume-max.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_volume-mute.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf audio-volume-muted.png stock_volume-mute.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf nm-device-wireless.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf network-idle.png nm-device-wireless.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf sunny.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf weather-clear.png sunny.png )
( cd usr/share/icons/gnome/32x32/status ; rm -rf stock_dialog-question.png )
( cd usr/share/icons/gnome/32x32/status ; ln -sf dialog-question.png stock_dialog-question.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-character-map.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-character-map.png gnome-character-map.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-settings-font.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-font.png gnome-settings-font.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf style.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-theme.png style.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-help.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png gnome-help.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xscreensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-screensaver.png xscreensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf screensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-screensaver.png screensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png gnome-settings-keybindings.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf locale.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-locale.png locale.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xfce4-backdrop.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-wallpaper.png xfce4-backdrop.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf openterm.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-terminal.png openterm.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf ksysguard.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-system-monitor.png ksysguard.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xfce4-mixer.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png xfce4-mixer.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-mixer.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png gnome-mixer.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf config-language.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-locale.png config-language.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf config-users.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-users.png config-users.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kcalc.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-calculator.png kcalc.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf wallpaper.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-wallpaper.png wallpaper.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-settings-background.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-wallpaper.png gnome-settings-background.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf accessibility-directory.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-accessibility.png accessibility-directory.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-terminal.png gnome-terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf update-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-software-update.png update-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf stock_help.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png stock_help.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-accessibility.png gnome-settings-accessibility-technologies.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf key_bindings.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-keyboard-shortcuts.png key_bindings.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kcmkwm.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-system-windows.png kcmkwm.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xfce-terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-terminal.png xfce-terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf volume-knob.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png volume-knob.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gucharmap.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-character-map.png gucharmap.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf multimedia.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png multimedia.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-monitor.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-system-monitor.png gnome-monitor.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kuser.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-users.png kuser.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf redhat-filemanager.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-file-manager.png redhat-filemanager.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf zen-icon.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-software-update.png zen-icon.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-settings-theme.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-theme.png gnome-settings-theme.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kedit.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-text-editor.png kedit.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf help.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png help.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xfce-filemanager.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-file-manager.png xfce-filemanager.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf calc.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-calculator.png calc.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kcharselect.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-character-map.png kcharselect.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf arts.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png arts.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-remote-desktop.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-remote-desktop.png gnome-remote-desktop.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gtk-help.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png gtk-help.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf background.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-wallpaper.png background.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf file-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-file-manager.png file-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-window-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-system-windows.png gnome-window-manager.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf access.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-accessibility.png access.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kfm.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-file-manager.png kfm.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kscreensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-screensaver.png kscreensaver.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf khelpcenter.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png khelpcenter.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf xfwm4.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-system-windows.png xfwm4.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kwin.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-system-windows.png kwin.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf gnome-calculator.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-calculator.png gnome-calculator.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf system-config-users.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf system-users.png system-config-users.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-terminal.png terminal.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf susehelpcenter.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf help-browser.png susehelpcenter.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf krfb.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-remote-desktop.png krfb.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf text-editor.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf accessories-text-editor.png text-editor.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf kcmsound.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf multimedia-volume-control.png kcmsound.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf konsole.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf utilities-terminal.png konsole.png )
( cd usr/share/icons/gnome/32x32/apps ; rm -rf fonts.png )
( cd usr/share/icons/gnome/32x32/apps ; ln -sf preferences-desktop-font.png fonts.png )
( cd usr/share/icons/gnome/32x32/animations ; rm -rf gnome-spinner-rest.png )
( cd usr/share/icons/gnome/32x32/animations ; ln -sf process-idle.png gnome-spinner-rest.png )
( cd usr/share/icons/gnome/32x32/animations ; rm -rf gnome-spinner.png )
( cd usr/share/icons/gnome/32x32/animations ; ln -sf process-working.png gnome-spinner.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-8.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-plain.png stock_smiley-8.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-15.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-cool.png stock_smiley-15.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-1.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-smile.png stock_smiley-1.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-11.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-crying.png stock_smiley-11.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-10.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-raspberry.png stock_smiley-10.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-2.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-smile.png stock_smiley-2.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-13.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-kiss.png stock_smiley-13.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-4.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-sad.png stock_smiley-4.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-5.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-surprise.png stock_smiley-5.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-3.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-wink.png stock_smiley-3.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-18.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-angel.png stock_smiley-18.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-7.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-smile.png stock_smiley-7.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-6.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-smile-big.png stock_smiley-6.png )
( cd usr/share/icons/gnome/32x32/emotes ; rm -rf stock_smiley-22.png )
( cd usr/share/icons/gnome/32x32/emotes ; ln -sf face-monkey.png stock_smiley-22.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-server.png gnome-mime-x-directory-nfs-server.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf novell-button.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf start-here.png novell-button.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf redhat-network-server.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-server.png redhat-network-server.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gtk-directory.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.png gtk-directory.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf desktop.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-desktop.png desktop.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-ssh.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-fs-ssh.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf distributor-logo.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf start-here.png distributor-logo.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-workgroup.png gnome-mime-x-directory-smb-workgroup.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf trashcan_empty.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-trash.png trashcan_empty.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-saved-search.png application-x-gnome-saved-search.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf xfce-trash_empty.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-trash.png xfce-trash_empty.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-ftp.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-fs-ftp.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gtk-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.icon gtk-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-stock-trash.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-trash.png gnome-stock-trash.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf emptytrash.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-trash.png emptytrash.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gtk-network.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-workgroup.png gtk-network.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf stock_folder.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.png stock_folder.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-main-menu.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf start-here.png gnome-main-menu.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-server.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-server.png gnome-fs-server.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-directory.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.png gnome-fs-directory.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf folder_home.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-home.png folder_home.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-share.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-fs-share.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf stock_folder.icon )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.icon stock_folder.icon )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-trash.png gnome-fs-trash-empty.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf network.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png network.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf inode-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.icon inode-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-network.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-workgroup.png gnome-fs-network.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-home.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-home.png gnome-fs-home.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-desktop.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf user-desktop.png gnome-fs-desktop.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-server.png gnome-mime-x-directory-smb-server.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-nfs.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-fs-nfs.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf network_local.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-workgroup.png network_local.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf inode-directory.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.png inode-directory.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-mime-x-directory-smb-share.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf server.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf network-server.png server.png )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder.icon gnome-fs-directory.icon )
( cd usr/share/icons/gnome/32x32/places ; rm -rf gnome-fs-smb.png )
( cd usr/share/icons/gnome/32x32/places ; ln -sf folder-remote.png gnome-fs-smb.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf viewmag-.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-out.png viewmag-.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_save.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save.png stock_save.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-run.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-run.png gnome-run.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf editdelete.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-delete.png editdelete.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf zoom-best-fit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-fit-best.png zoom-best-fit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_pause.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-pause.png player_pause.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_end.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-forward.png player_end.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-last.png gtk-goto-last-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_right.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-next.png stock_right.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_up.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-up.png stock_up.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_spellcheck.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf tools-check-spelling.png stock_spellcheck.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf editcopy.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-copy.png editcopy.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_delete.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-delete.png stock_delete.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_home.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-home.png stock_home.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf kfm_home.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-home.png kfm_home.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-cancel.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf process-stop.png gtk-cancel.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_right.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-right.png stock_text_right.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-zoom-out.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-out.png gtk-zoom-out.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf mail_replyall.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-reply-all.png mail_replyall.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-dir.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf folder-new.png stock_new-dir.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf rightjust.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-right.png rightjust.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-new.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-new.png gtk-new.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-backward.png gtk-media-rewind-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_undo.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-undo.png stock_undo.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-about.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf help-about.png gtk-about.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-indent-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-more.png gtk-indent-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-close.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf window-close.png gtk-close.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-sort-descending.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-sort-descending.png gtk-sort-descending.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf mail_forward.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-forward.png mail_forward.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf editcut.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-cut.png editcut.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-select-all.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-select-all.png gtk-select-all.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf process-stop.png gtk-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_save-as.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save-as.png stock_save-as.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-undo-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-undo.png gtk-undo-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_zoom-1.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-original.png stock_zoom-1.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-forward.png stock_media-fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf mail_new.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-message-new.png mail_new.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-top.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-top.png gtk-goto-top.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_search.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find.png stock_search.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf lock.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-lock-screen.png lock.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-justify-right.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-right.png gtk-justify-right.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-next.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-forward.png stock_media-next.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-less.png gnome-stock-text-unindent.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-start.png gtk-media-play-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_center.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-center.png stock_text_center.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_add-bookmark.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf bookmark-new.png stock_add-bookmark.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-reply-all.png stock_mail-reply-to-all.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-record.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-record.png gtk-media-record.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-justify-center.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-center.png gtk-justify-center.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf kfind.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-search.png kfind.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-bcard.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf contact-new.png stock_new-bcard.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf viewmag+.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-in.png viewmag+.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf reload_page.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png reload_page.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-underline.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-underline.png gtk-underline.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf folder_new.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf folder-new.png folder_new.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-revert.png gtk-revert-to-saved-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-clear.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-clear.png gtk-clear.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf process-stop.png stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-next.png gtk-go-forward-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-forward.png gtk-media-previous-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-bottom.png gtk-goto-bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-zoom-100.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-original.png gtk-zoom-100.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf fileopen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-open.png fileopen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-zoom-fit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-fit-best.png gtk-zoom-fit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf mail_send.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-send.png mail_send.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf filesaveas.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save-as.png filesaveas.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf redhat-home.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-home.png redhat-home.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-forward.png gtk-media-next-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-bottom.png stock_bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-jump.png gtk-jump-to-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-stop.png gtk-media-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf previous.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-previous.png previous.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-fullscreen.png gtk-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-print.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print.png gtk-print.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_zoom-in.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-in.png stock_zoom-in.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_redo.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-redo.png stock_redo.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_first.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-first.png stock_first.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-cut.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-cut.png gtk-cut.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf reload3.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png reload3.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-prev.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-backward.png stock_media-prev.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-revert.png gtk-revert-to-saved-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-print-preview.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print-preview.png gtk-print-preview.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf bookmark_add.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf bookmark-new.png bookmark_add.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-bottom.png bottom.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_properties.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-properties.png stock_properties.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-stop.png player_stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_rew.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-backward.png player_rew.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf viewmagfit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-fit-best.png viewmagfit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf process-stop.png stock_stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-reply-sender.png gnome-stock-mail-rpl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_select-all.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-select-all.png stock_select-all.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_top.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-top.png stock_top.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-more.png gtk-unindent-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf exit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf application-exit.png exit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-italic.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-italic.png gtk-italic.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf viewmag1.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-original.png viewmag1.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf xfce-system-exit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf application-exit.png xfce-system-exit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf revert.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-revert.png revert.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text-strikethrough.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-strikethrough.png stock_text-strikethrough.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-send.png gnome-stock-mail-snd.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-find-and-replace.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find-replace.png gtk-find-and-replace.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf bookmark-new.png stock_help-add-bookmark.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-quit.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf application-exit.png gtk-quit.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-previous.png gtk-go-forward-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-reply.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-reply-sender.png stock_mail-reply.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-zoom-in.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-in.png gtk-zoom-in.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf window_nofullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-restore.png window_nofullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-jump.png gtk-jump-to-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf redo.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-redo.png redo.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf text_strike.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-strikethrough.png text_strike.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_left.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-left.png stock_text_left.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_about.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf help-about.png stock_about.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf reload_all_tabs.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png reload_all_tabs.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_zoom-out.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-out.png stock_zoom-out.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf mail_reply.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-reply-sender.png mail_reply.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf editpaste.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-paste.png editpaste.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_indent.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-more.png stock_text_indent.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-lockscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-lock-screen.png gnome-lockscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_print-setup.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-page-setup.png stock_print-setup.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-down.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-down.png gtk-go-down.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_italic.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-italic.png stock_text_italic.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf xfce-system-lock.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-lock-screen.png xfce-system-lock.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf add.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf list-add.png add.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-redo-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-redo.png gtk-redo-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-forward.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-forward.png stock_mail-forward.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_last.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-last.png stock_last.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf bookmarks_list_add.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf bookmark-new.png bookmarks_list_add.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_underlined.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-underline.png stock_text_underlined.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-last.png gtk-goto-first-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf filesave.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save.png filesave.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-forward.png gtk-media-rewind-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-justify-fill.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-fill.png gtk-justify-fill.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-indent-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-less.png gtk-indent-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf down.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-down.png down.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-send.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-send.png stock_mail-send.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-more.png gnome-stock-text-indent.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_close.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf window-close.png stock_close.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf search.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-search.png search.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_zoom-page.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf zoom-fit-best.png stock_zoom-page.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-compose.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-message-new.png stock_mail-compose.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf next.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-next.png next.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-spell-check.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf tools-check-spelling.png gtk-spell-check.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-searchtool.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-search.png gnome-searchtool.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-justify-left.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-left.png gtk-justify-left.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf remove.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf list-remove.png remove.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-up.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-up.png gtk-go-up.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-find.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find.png gtk-find.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-less.png gtk-unindent-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-delete.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-delete.png gtk-delete.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-remove.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf list-remove.png gtk-remove.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-pause.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-pause.png gtk-media-pause.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-rec.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-record.png stock_media-rec.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-forward.png gnome-stock-mail-fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-restore.png gtk-leave-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf text_italic.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-italic.png text_italic.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-appointment.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf appointment-new.png stock_new-appointment.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-message-new.png gnome-stock-mail-new.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-bold.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-bold.png gtk-bold.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-home.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-home.png gtk-home.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_paste.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-paste.png stock_paste.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_record.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-record.png player_record.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_refresh.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png stock_refresh.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf editclear.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-clear.png editclear.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_down.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-down.png stock_down.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-refresh.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png gtk-refresh.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-forward.png gtk-media-forward-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf text_under.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-underline.png text_under.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf filenew.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-new.png filenew.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-address-book.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf address-book-new.png stock_new-address-book.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_print-preview.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print-preview.png stock_print-preview.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf filequickprint.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print-preview.png filequickprint.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-backward.png gtk-media-forward-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_search-and-replace.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find-replace.png stock_search-and-replace.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf window_fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-fullscreen.png window_fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf forward.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-next.png forward.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-paste.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-paste.png gtk-paste.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf leftjust.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-left.png leftjust.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-copy.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-copy.png gtk-copy.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf up.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-up.png up.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-previous.png gtk-go-back-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-forward.png player_fwd.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf text_bold.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-bold.png text_bold.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-pause.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-pause.png stock_media-pause.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-save-as.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save-as.png gtk-save-as.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf window_new.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf window-new.png window_new.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gohome.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-home.png gohome.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-execute.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-run.png gtk-execute.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-first.png gtk-goto-last-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-restore.png stock_leave-fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gnome-logout.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf system-log-out.png gnome-logout.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_justify.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-fill.png stock_text_justify.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf top.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-top.png top.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-fullscreen.png stock_fullscreen.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-strikethrough.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-strikethrough.png gtk-strikethrough.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-window.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf window-new.png stock_new-window.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_play.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-start.png player_play.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-next.png gtk-go-back-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf filefind.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find.png filefind.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf back.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-previous.png back.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf undo.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-undo.png undo.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_new-text.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-new.png stock_new-text.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf reload.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-refresh.png reload.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_start.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-backward.png player_start.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf player_eject.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-eject.png player_eject.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-backward.png gtk-media-previous-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf fileprint.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print.png fileprint.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_left.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-previous.png stock_left.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-first.png gtk-goto-first-ltr.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_cut.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-cut.png stock_cut.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf find.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-find.png find.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf finish.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-last.png finish.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-play.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-start.png stock_media-play.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_unindent.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-indent-less.png stock_text_unindent.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-open.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-open.png gtk-open.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_file-properites.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-properties.png stock_file-properites.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf start.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf go-first.png start.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-sort-ascending.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf view-sort-ascending.png gtk-sort-ascending.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-save.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-save.png gtk-save.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf centrejust.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-justify-center.png centrejust.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_mail-send-receive.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf mail-send-receive.png stock_mail-send-receive.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_print.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-print.png stock_print.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-skip-backward.png gtk-media-next-rtl.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-properties.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf document-properties.png gtk-properties.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-playback-stop.png stock_media-stop.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_copy.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf edit-copy.png stock_copy.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_media-rew.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf media-seek-backward.png stock_media-rew.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf stock_text_bold.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf format-text-bold.png stock_text_bold.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf gtk-add.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf list-add.png gtk-add.png )
( cd usr/share/icons/gnome/32x32/actions ; rm -rf appointment.png )
( cd usr/share/icons/gnome/32x32/actions ; ln -sf appointment-new.png appointment.png )
